package data

// Wall of text disclaimer about why names are difficult below - Read at your own
// peril.

// Names are a little tricky - to make a meaningful combination of family and given
// names, you need to take culture into account - some cultures do family-given,
// others do given-family, some have more complicated naming conventions etc.

// Additionally, sometimes you might want a name as it's spelled in a specific langauge,
// with that languages characterset, and other times you might want it spelled in your
// in a "romanized" characterset.

// Further, if you intend to have generate a list of names that would traditionally
// be associated with a given gender, you need to account for names that could
// belong to both (reasonably - clearly, every name could belong to any gender, but
// in the case where you want a name that sounds natively like one that would be assigned
// to a person of a certain gender in that languages culture for the sake of displaying
// "realistic" results... it's not so simple).

// Initially, I set out to capture all these complexities, but realized I could get
// a "good enough" set of base tools in place where people could mostly model the needed
// parts in Moldovas templating language alone. So, here is currently what is supported:

// There is a collection of First and Last names, which contain a map[string]string
// of languags to spellings of that name in that language. Where possible, unicode
// character names are supported/favored over non unicode. Each name has a "Default"
// that should be used when the chosen language is not present in the map. In this way,
// A best-effort attempt can be made to support any language, but falling back to
// a good-enough representation where ncessary.

// If you would like to see a new set of names added, please open a PR
// and provide some reference to where these names can be found for that language.

// English language
const English = "english"

// Dutch language
const Dutch = "dutch"

// Japanese language
const Japanese = "japanese"

// Romanian language
const Romanian = "romanian"

// Chinese language
const Chinese = "chinese"

// Korean language
const Korean = "korean"

// Spanish language
const Spanish = "spanish"

// German language
const German = "german"

// Swahili language
const Swahili = "swahili"

// Russian language
const Russian = "russian"

// Portugeuse language
const Portuguese = "portuguese"

// French language
const French = "french"

// Latin language
const Latin = "latin"

// Italian language
const Italian = "italian"

// Catalan language
const Catalan = "catalan"

// Hungrian language
const Hungarian = "hungarian"

// Finnish language
const Finnish = "finnish"

// Lithuanian language
const Lithuanian = "lithuanian"

// Greek language
const Greek = "greek"

// Czech language
const Czech = "czech"

// Polish language
const Polish = "polish"

// Ukrainian language
const Ukrainian = "ukrainian"

// Arabic language
const Arabic = "arabic"

// Langauges is a list of possible languages for which Moldova can generate names
var Langauges = []string{
	English,
	Dutch,
	Japanese,
	Romanian,
	Chinese,
	Korean,
	Spanish,
	German,
	Swahili,
	Russian,
	Portuguese,
	French,
	Latin,
	Italian,
	Catalan,
	Arabic,
	Ukrainian,
	Polish,
	Czech,
	Greek,
	Hungarian,
	Finnish,
	Lithuanian,
}

// Name represents a name, Family or Given, that has both a traditional and a romanized
// version of the text, depending on the needs of the user
type Name struct {
	defaultLanguage string
	spellings       map[string]string
}

type spellings map[string]string

func KnownLanguage(lang string) bool {
	for _, l := range Langauges {
		if l == lang {
			return true
		}
	}
	return false
}

// GetSpelling will return the first match found for the provided list of languages, in the
// order in which they were passed in
func (n *Name) GetSpelling(languages ...string) string {
	for _, l := range languages {
		if name, ok := n.spellings[l]; ok && name != "" {
			return name
		}
	}
	return n.spellings[n.defaultLanguage]
}

// FirstNames is a collection of first names, with a best-effort approach to supporting
// a given name in multiple languages/cultures at one time. Currently, it's mostly
// English / European names, because I found a very convenient CSV with the data to
// crib from. Please contribute any missing languages to existing names, or new names
// with as many different languages as you can!
var FirstNames = []*Name{
	&Name{English, spellings{English: "Aaron", German: "Aaron", Dutch: "Aäron", Latin: "Aaron", French: "Aaron", Italian: "Aronne", Spanish: "Aarón", Catalan: "Aaró", Portuguese: "Aarão", Romanian: "Aron"}},
	&Name{English, spellings{English: "Abel", German: "Abel", Dutch: "Abel", Latin: "Abel", French: "Abel", Italian: "Abele", Spanish: "Abel", Catalan: "Abel", Portuguese: "Abel", Romanian: ""}},
	&Name{English, spellings{English: "Abraham", German: "Abraham", Dutch: "Abraham", Latin: "Abraham", French: "Abraham", Italian: "Abramo", Spanish: "Abraham", Catalan: "Abraham", Portuguese: "Abraão", Romanian: "Avram"}},
	&Name{English, spellings{English: "Adam", German: "Adam", Dutch: "Adam", Latin: "Adamus", French: "Adam", Italian: "Adamo", Spanish: "Adán", Catalan: "Adam", Portuguese: "Adão", Romanian: "Adam"}},
	&Name{English, spellings{English: "Adrian", German: "Adrian", Dutch: "Adriaan", Latin: "Adrianus", French: "Adrien", Italian: "Adriano", Spanish: "Adrián", Catalan: "Adrià", Portuguese: "Adriano", Romanian: "Adrian"}},
	&Name{English, spellings{English: "Athanasius", German: "Athanas", Dutch: "Athanasius", Latin: "Athanasius", French: "Athanase", Italian: "Atanasio", Spanish: "Atanasio", Catalan: "Atanasi", Portuguese: "Afanásio", Romanian: "Atanasie"}},
	&Name{English, spellings{English: "Agatho", German: "", Dutch: "Agatho", Latin: "Agatho", French: "Agathon", Italian: "Agatone", Spanish: "Agatón", Catalan: "Agató", Portuguese: "Agatão", Romanian: ""}},
	&Name{English, spellings{English: "Alan", German: "Alan", Dutch: "Alan", Latin: "Alanus", French: "Alain", Italian: "Alano", Spanish: "Alano", Catalan: "Alà", Portuguese: "Alan", Romanian: ""}},
	&Name{English, spellings{English: "Albert", German: "Albert", Dutch: "Albert", Latin: "Albertus", French: "Albert", Italian: "Alberto", Spanish: "Alberto", Catalan: "Albert", Portuguese: "Alberto", Romanian: "Albert"}},
	&Name{English, spellings{English: "Alexander", German: "Alexander", Dutch: "Alexander", Latin: "Alexander", French: "Alexandre", Italian: "Alessandro", Spanish: "Alejandro", Catalan: "Alexandre", Portuguese: "Alexandre", Romanian: "Alexandru"}},
	&Name{English, spellings{English: "Alexis", German: "Alexius", Dutch: "Alexius", Latin: "Alexius", French: "Alexis", Italian: "Alessio", Spanish: "Alejo", Catalan: "Aleix", Portuguese: "Aleixo", Romanian: ""}},
	&Name{English, spellings{English: "Alphonso", German: "Alfons", Dutch: "Alfons", Latin: "Alphonsus", French: "Alphonse", Italian: "Alfonso", Spanish: "Alfonso", Catalan: "Alfons", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Alfred", German: "Alfred", Dutch: "Alfred", Latin: "", French: "Alfred", Italian: "Alfredo", Spanish: "Alfredo", Catalan: "Alfred", Portuguese: "Alfredo", Romanian: "Alfred"}},
	&Name{English, spellings{English: "Alvarus", German: "", Dutch: "", Latin: "", French: "", Italian: "Alvaro", Spanish: "Álvaro", Catalan: "Àlvar", Portuguese: "Álvaro", Romanian: ""}},
	&Name{English, spellings{English: "Alvin", German: "Adelwin", Dutch: "Adelwijn", Latin: "", French: "", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Ambrose", German: "Ambros", Dutch: "Ambrosius", Latin: "Ambrosius", French: "Ambroise", Italian: "Ambrosio", Spanish: "Ambrosio", Catalan: "Ambrós", Portuguese: "Ambrósio", Romanian: "Ambrozie"}},
	&Name{English, spellings{English: "Anatolius", German: "", Dutch: "Anatolius", Latin: "Anatolius", French: "Anatole", Italian: "Anatolio", Spanish: "Anatolio", Catalan: "", Portuguese: "Anatólio", Romanian: "Anatol"}},
	&Name{English, spellings{English: "Andrew", German: "Andreas", Dutch: "Andreas", Latin: "Andreas", French: "André", Italian: "Andrea", Spanish: "Andrés", Catalan: "Andreu", Portuguese: "André", Romanian: "Andrei"}},
	&Name{English, spellings{English: "Anthony", German: "Anton", Dutch: "Anton", Latin: "Antonius", French: "Antoine", Italian: "Antonio", Spanish: "Antonio", Catalan: "Antoni", Portuguese: "António", Romanian: "Anton"}},
	&Name{English, spellings{English: "Apollinaris", German: "", Dutch: "Apollinaris", Latin: "Apollinaris", French: "Apollinaire", Italian: "Apollinare", Spanish: "Apolinar", Catalan: "Apollinar", Portuguese: "Apolinário", Romanian: ""}},
	&Name{English, spellings{English: "Apollonius", German: "", Dutch: "Apollonius", Latin: "Apollonius", French: "", Italian: "Apollonio", Spanish: "Apolonio", Catalan: "Apolloni", Portuguese: "Apolónio", Romanian: ""}},
	&Name{English, spellings{English: "Arcadius", German: "", Dutch: "Arcadius", Latin: "Arcadius", French: "Arcade", Italian: "Arcadio", Spanish: "Arcadio", Catalan: "Arcadi", Portuguese: "Arcádio", Romanian: "Arcadie"}},
	&Name{English, spellings{English: "Archibald", German: "Archibald", Dutch: "Archibald", Latin: "", French: "Archimbaud", Italian: "Arcibaldo", Spanish: "Archibaldo", Catalan: "", Portuguese: "Arquibaldo", Romanian: ""}},
	&Name{English, spellings{English: "Aristarchus", German: "", Dutch: "Aristarchus", Latin: "Aristarchus", French: "", Italian: "Aristarco", Spanish: "Aristarco", Catalan: "", Portuguese: "Aristarco", Romanian: ""}},
	&Name{English, spellings{English: "Arnold", German: "Arnold", Dutch: "Arnold", Latin: "", French: "Arnaud", Italian: "Arnoldo", Spanish: "Arnaldo", Catalan: "Arnald", Portuguese: "Arnaldo", Romanian: "Arnold"}},
	&Name{English, spellings{English: "Arsenius", German: "", Dutch: "Arsenius", Latin: "Arsenius", French: "Arsène", Italian: "Arsenio", Spanish: "Arsenio", Catalan: "Arsénio", Portuguese: "Arseni", Romanian: "Arsenie"}},
	&Name{English, spellings{English: "Arthur", German: "Arthur", Dutch: "Arthur", Latin: "Arthurus", French: "Arthur", Italian: "Arturo", Spanish: "Arturo", Catalan: "Artur", Portuguese: "Artur", Romanian: "Artur"}},
	&Name{English, spellings{English: "August", German: "August", Dutch: "Augustus", Latin: "Augustus", French: "Auguste", Italian: "Augusto", Spanish: "Agustín", Catalan: "August", Portuguese: "Augusto", Romanian: "Augustin"}},
	&Name{English, spellings{English: "Baldwin", German: "Balduin", Dutch: "Boudewijn", Latin: "", French: "Baudoin", Italian: "Balduino", Spanish: "Balduino", Catalan: "Baldui", Portuguese: "Balduíno", Romanian: ""}},
	&Name{English, spellings{English: "Basil", German: "Basilius", Dutch: "Basilius", Latin: "Basilius", French: "Basile", Italian: "Basilio", Spanish: "Basilio", Catalan: "Basili", Portuguese: "Basílio", Romanian: "Vasile"}},
	&Name{English, spellings{English: "Benedick", German: "Benedikt", Dutch: "Benedikt", Latin: "Benedictus", French: "Benoît", Italian: "Benedetto", Spanish: "Benito", Catalan: "Benet", Portuguese: "Bento", Romanian: ""}},
	&Name{English, spellings{English: "Benjamin", German: "Benjamin", Dutch: "Benjamin", Latin: "Beniamin", French: "Benjamin", Italian: "Beniamino", Spanish: "Benjamín", Catalan: "Benjamí", Portuguese: "Benjamim", Romanian: ""}},
	&Name{English, spellings{English: "Bernard", German: "Bernhard", Dutch: "Bernard", Latin: "", French: "Bernard", Italian: "Bernardo", Spanish: "Bernardo", Catalan: "Bernat", Portuguese: "Bernardo", Romanian: ""}},
	&Name{English, spellings{English: "Bertram", German: "Bertram", Dutch: "Bertram", Latin: "", French: "Bertrand", Italian: "Bertrando", Spanish: "Bertrán", Catalan: "Beltran", Portuguese: "Beltrão", Romanian: ""}},
	&Name{English, spellings{English: "Blase", German: "Blas", Dutch: "Blasius", Latin: "Blasius", French: "Blaise", Italian: "Biagio", Spanish: "Blas", Catalan: "Blai", Portuguese: "Brás", Romanian: ""}},
	&Name{English, spellings{English: "Boniface", German: "Bonifaz", Dutch: "Bonifatius", Latin: "Bonifatius", French: "Boniface", Italian: "Bonifacio", Spanish: "Bonifacio", Catalan: "Bonifaci", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Boris", German: "Boris", Dutch: "Boris", Latin: "Liborius", French: "Boris", Italian: "Boris", Spanish: "Boris", Catalan: "Boris", Portuguese: "Bóris", Romanian: ""}},
	&Name{English, spellings{English: "Brian", German: "Brian", Dutch: "Brian", Latin: "", French: "Brian", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Bruno", German: "Bruno", Dutch: "Bruno", Latin: "", French: "Bruno", Italian: "Bruno", Spanish: "Bruno", Catalan: "Bru", Portuguese: "Bruno", Romanian: ""}},
	&Name{English, spellings{English: "Caesar", German: "Cäsar", Dutch: "Cesar", Latin: "Caesar", French: "César", Italian: "Cesare", Spanish: "César", Catalan: "Cèsar", Portuguese: "César", Romanian: "Cezar"}},
	&Name{English, spellings{English: "Camillus", German: "Kamil", Dutch: "Camiel", Latin: "Camillus", French: "Camille", Italian: "Camillo", Spanish: "Camilo", Catalan: "Camil", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Casimir", German: "Kasimir", Dutch: "Casimier", Latin: "", French: "Casimir", Italian: "Casimiro", Spanish: "Casimiro", Catalan: "Casimir", Portuguese: "Casimiro", Romanian: "Cazimir"}},
	&Name{English, spellings{English: "Cecil", German: "", Dutch: "Ceciel", Latin: "Caecilius", French: "Cécile", Italian: "Cecilio", Spanish: "Cecilio", Catalan: "Cecili", Portuguese: "Cecílio", Romanian: "Cecil"}},
	&Name{English, spellings{English: "Charles", German: "Karl", Dutch: "Karel", Latin: "Carolus", French: "Charles", Italian: "Carlo", Spanish: "Carlos", Catalan: "Carles", Portuguese: "Carlos", Romanian: "Carol"}},
	&Name{English, spellings{English: "Christian", German: "Kristian", Dutch: "Christiaan", Latin: "Christianus", French: "Christian", Italian: "Cristiano", Spanish: "Cristián", Catalan: "", Portuguese: "Cristiano", Romanian: "Cristian"}},
	&Name{English, spellings{English: "Christopher", German: "Christoph", Dutch: "Christoffel", Latin: "Christophorus", French: "Christophe", Italian: "Cristoforo", Spanish: "Cristóbal", Catalan: "", Portuguese: "Cristóvão", Romanian: "Cristofor"}},
	&Name{English, spellings{English: "Clarence", German: "", Dutch: "Clarence", Latin: "", French: "", Italian: "Clarenzio", Spanish: "", Catalan: "Clarenci", Portuguese: "Clarencio", Romanian: ""}},
	&Name{English, spellings{English: "Claude", German: "Klaudius", Dutch: "Claudius", Latin: "Claudius", French: "Claude", Italian: "Claudio", Spanish: "Claudio", Catalan: "Claudi", Portuguese: "Cláudio", Romanian: "Claudiu"}},
	&Name{English, spellings{English: "Clement", German: "Klemens", Dutch: "Clemens", Latin: "Clemens", French: "Clément", Italian: "Clemente", Spanish: "Clemente", Catalan: "Climent", Portuguese: "Clemente", Romanian: ""}},
	&Name{English, spellings{English: "Colin", German: "Klaus", Dutch: "Klaas", Latin: "", French: "Colin", Italian: "Nicolino", Spanish: "Colás", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Conrad", German: "Konrad", Dutch: "Koenraad", Latin: "Conradus", French: "Conrad", Italian: "Corrado", Spanish: "Conrado", Catalan: "Conrad", Portuguese: "Conrado", Romanian: ""}},
	&Name{English, spellings{English: "Constantine", German: "Konstantin", Dutch: "Constantijn", Latin: "Constantinus", French: "Constantin", Italian: "Costantino", Spanish: "Constantino", Catalan: "Constantí", Portuguese: "Constantino", Romanian: ""}},
	&Name{English, spellings{English: "Cornelius", German: "Kornelius", Dutch: "Cornelis", Latin: "Cornelius", French: "Corneille", Italian: "Cornelio", Spanish: "Cornelio", Catalan: "Corneli", Portuguese: "Cornélio", Romanian: "Corneliu"}},
	&Name{English, spellings{English: "Cyprian", German: "Zyprian", Dutch: "Cypriaan", Latin: "Cyprianus", French: "Cyprien", Italian: "Cipriano", Spanish: "Ciprián", Catalan: "Ciprià", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Cyril", German: "Kyrill", Dutch: "Cyriel", Latin: "Cyrillus", French: "Cyrille", Italian: "Cirillo", Spanish: "Cirilo", Catalan: "Cirili", Portuguese: "Cirilo", Romanian: "Chirilǎ"}},
	&Name{English, spellings{English: "Cyrus", German: "", Dutch: "Cyrus", Latin: "Cyrus", French: "", Italian: "Ciro", Spanish: "Ciro", Catalan: "", Portuguese: "Ciro", Romanian: ""}},
	&Name{English, spellings{English: "Damian", German: "Damian", Dutch: "Damiaan", Latin: "Damianus", French: "Damien", Italian: "Damiano", Spanish: "Damián", Catalan: "Damià", Portuguese: "Damião", Romanian: "Damian"}},
	&Name{English, spellings{English: "Daniel", German: "Daniel", Dutch: "Daniël", Latin: "Daniel", French: "Daniel", Italian: "Daniele", Spanish: "Daniel", Catalan: "Daniel", Portuguese: "Daniel", Romanian: "Dǎnilǎ"}},
	&Name{English, spellings{English: "Darius", German: "Darius", Dutch: "Darius", Latin: "Dareus", French: "", Italian: "Dario", Spanish: "Darío", Catalan: "", Portuguese: "Dário", Romanian: "Darius"}},
	&Name{English, spellings{English: "David", German: "David", Dutch: "David", Latin: "David", French: "David", Italian: "Davide", Spanish: "David", Catalan: "David", Portuguese: "David", Romanian: ""}},
	&Name{English, spellings{English: "Dennis", German: "Dennis", Dutch: "Dennis", Latin: "Dionysius", French: "Denis", Italian: "Dionigi", Spanish: "Dionisio", Catalan: "Dionís", Portuguese: "Dinis", Romanian: "Dionisie"}},
	&Name{English, spellings{English: "Derreck", German: "", Dutch: "Diederik", Latin: "Theoderic", French: "", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Dimitry", German: "", Dutch: "Dimitri", Latin: "Demetrius", French: "Dimitri", Italian: "Demetrio", Spanish: "Demetrio", Catalan: "", Portuguese: "Demétrio", Romanian: "Dumitru"}},
	&Name{English, spellings{English: "Dominic", German: "Dominik", Dutch: "Dominiek", Latin: "Dominicus", French: "Dominique", Italian: "Domenico", Spanish: "Domingo", Catalan: "Domènec", Portuguese: "Domingos", Romanian: ""}},
	&Name{English, spellings{English: "Donald", German: "Donald", Dutch: "Donald", Latin: "Donivaldus", French: "Donald", Italian: "", Spanish: "Donaldo", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Donatus", German: "Donatus", Dutch: "Donaat", Latin: "Donatus", French: "Donate", Italian: "Donato", Spanish: "Donato", Catalan: "Donat", Portuguese: "Donato", Romanian: ""}},
	&Name{English, spellings{English: "Dorian", German: "", Dutch: "Dorian", Latin: "Dorianus", French: "", Italian: "Doriano", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Edgar", German: "Edgar", Dutch: "Edgar", Latin: "", French: "Edgar", Italian: "Edgardo", Spanish: "Édgar", Catalan: "", Portuguese: "Edgar", Romanian: ""}},
	&Name{English, spellings{English: "Edmund", German: "Edmund", Dutch: "Edmond", Latin: "", French: "Edmond", Italian: "Edmondo", Spanish: "Edmundo", Catalan: "", Portuguese: "Edmundo", Romanian: ""}},
	&Name{English, spellings{English: "Edward", German: "Eduard", Dutch: "Eduard", Latin: "Eduardus", French: "Édouard", Italian: "Edoardo", Spanish: "Eduardo", Catalan: "Eduard", Portuguese: "Eduardo", Romanian: ""}},
	&Name{English, spellings{English: "Edwin", German: "Edwin", Dutch: "Edwin", Latin: "", French: "", Italian: "Edvino", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Ephraim", German: "Ephraim", Dutch: "Efraïm", Latin: "Ephraim", French: "Ephrem", Italian: "Efrem", Spanish: "Efraín", Catalan: "", Portuguese: "Efraim", Romanian: ""}},
	&Name{English, spellings{English: "Elias", German: "Elias", Dutch: "Elias", Latin: "Elias", French: "Élie", Italian: "Elia", Spanish: "Elías", Catalan: "", Portuguese: "Elias", Romanian: "Ilie"}},
	&Name{English, spellings{English: "Eliezer", German: "", Dutch: "Eleazar", Latin: "", French: "", Italian: "Eleazaro", Spanish: "Eliazar", Catalan: "", Portuguese: "Eleazar", Romanian: ""}},
	&Name{English, spellings{English: "Elliot", German: "", Dutch: "", Latin: "", French: "", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Emile", German: "Emil", Dutch: "Emiel", Latin: "Aemilius", French: "Émile", Italian: "Emilio", Spanish: "Emilio", Catalan: "Emili", Portuguese: "Emílio", Romanian: "Emil"}},
	&Name{English, spellings{English: "Emmanuel", German: "Immanuel", Dutch: "Emmanuël", Latin: "Emmanuel", French: "Emmanuel", Italian: "Emanuele", Spanish: "Emanuel", Catalan: "Manel", Portuguese: "Emanuel", Romanian: "Emanoil"}},
	&Name{English, spellings{English: "Erastus", German: "", Dutch: "Erastus", Latin: "", French: "", Italian: "Erasto", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Ernest", German: "Ernst", Dutch: "Ernst", Latin: "", French: "Ernest", Italian: "Ernesto", Spanish: "Ernesto", Catalan: "Ernest", Portuguese: "Ernesto", Romanian: ""}},
	&Name{English, spellings{English: "Erwin", German: "Erwin", Dutch: "Erwin", Latin: "Erwin", French: "", Italian: "Ervino", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Eugene", German: "Eugen", Dutch: "Eugène", Latin: "Eugenius", French: "Eugène", Italian: "Eugenio", Spanish: "Eugenio", Catalan: "Eugeni", Portuguese: "Eugénio", Romanian: "Eugen"}},
	&Name{English, spellings{English: "Eustratus", German: "", Dutch: "", Latin: "Eustratus", French: "", Italian: "Eustrato", Spanish: "Eustrato", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Fabian", German: "Fabian", Dutch: "Fabiaan", Latin: "Fabianus", French: "Fabien", Italian: "Fabiano", Spanish: "Fabián", Catalan: "Fabià", Portuguese: "Fábio", Romanian: "Fabian"}},
	&Name{English, spellings{English: "Felix", German: "Felix", Dutch: "Felix", Latin: "Felix", French: "Félix", Italian: "Felice", Spanish: "Félix", Catalan: "Félix", Portuguese: "Félix", Romanian: "Felix"}},
	&Name{English, spellings{English: "Ferdinand", German: "Ferdinand", Dutch: "Ferdinand", Latin: "Ferdinand", French: "Fernand", Italian: "Fernando", Spanish: "Fernando", Catalan: "Ferran", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Florian", German: "Florian", Dutch: "Floriaan", Latin: "Florianus", French: "Florien", Italian: "Floriano", Spanish: "Florián", Catalan: "Florià", Portuguese: "Floriano", Romanian: "Florin"}},
	&Name{English, spellings{English: "Francis", German: "Franziskus", Dutch: "Franciscus", Latin: "Franciscus", French: "Françique", Italian: "Francesco", Spanish: "Francisco", Catalan: "Francesc", Portuguese: "Francisco", Romanian: "Francisc"}},
	&Name{English, spellings{English: "Frederick", German: "Friedrich", Dutch: "Frederik", Latin: "Fredericus", French: "Frédéric", Italian: "Federico", Spanish: "Federico", Catalan: "Frederic", Portuguese: "Frederico", Romanian: ""}},
	&Name{English, spellings{English: "Gabriel", German: "Gabriel", Dutch: "Gabriël", Latin: "Gabriel", French: "Gabriel", Italian: "Gabriele", Spanish: "Gabriel", Catalan: "Gabriel", Portuguese: "Gabriel", Romanian: "Gavrilǎ"}},
	&Name{English, spellings{English: "Garrett", German: "Gerhard", Dutch: "Gerard", Latin: "Gerardus", French: "Gérard", Italian: "Gerardo", Spanish: "Gerardo", Catalan: "Gerard", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Gideon", German: "Gideon", Dutch: "Gideon", Latin: "", French: "Gédéon", Italian: "Gedeone", Spanish: "Gedeón", Catalan: "", Portuguese: "Gideão", Romanian: ""}},
	&Name{English, spellings{English: "Geoffrey", German: "Gottfried", Dutch: "Godfried", Latin: "Galfridus", French: "Geoffroy", Italian: "Goffredo", Spanish: "Godofredo", Catalan: "Godofred", Portuguese: "Godofredo", Romanian: ""}},
	&Name{English, spellings{English: "George", German: "Georg", Dutch: "George", Latin: "Georgius", French: "Georges", Italian: "Giorgio", Spanish: "Jorge", Catalan: "Jordi", Portuguese: "Jorge", Romanian: "Gheorghe"}},
	&Name{English, spellings{English: "Gerald", German: "Gerald", Dutch: "Gerout", Latin: "Geraldus", French: "Gérald", Italian: "Geraldo", Spanish: "Geraldo", Catalan: "", Portuguese: "Geraldo", Romanian: ""}},
	&Name{English, spellings{English: "Gerard", German: "Gerhard", Dutch: "Gerard", Latin: "Gerardus", French: "Gérard", Italian: "Gerardo", Spanish: "Gerardo", Catalan: "Gerard", Portuguese: "Gerardo", Romanian: ""}},
	&Name{English, spellings{English: "Gerasimus", German: "", Dutch: "Gerasimus", Latin: "Gerasimus", French: "", Italian: "Gerasimo", Spanish: "Gerásimo", Catalan: "", Portuguese: "Gherasim", Romanian: ""}},
	&Name{English, spellings{English: "Gilbert", German: "Gilbert", Dutch: "Gilbert", Latin: "", French: "Gilbert", Italian: "Gilberto", Spanish: "Gilberto", Catalan: "", Portuguese: "Gilberto", Romanian: ""}},
	&Name{English, spellings{English: "Godwin", German: "Gottwin", Dutch: "Gozewijn", Latin: "", French: "", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Gonzalo", German: "", Dutch: "", Latin: "", French: "Gonzague", Italian: "", Spanish: "Gonzalo", Catalan: "Gonçal", Portuguese: "Gonçalo", Romanian: ""}},
	&Name{English, spellings{English: "Gregory", German: "Gregor", Dutch: "Gregoor", Latin: "Gregorius", French: "Grégoire", Italian: "Gregorio", Spanish: "Gregorio", Catalan: "Gregori", Portuguese: "Gregório", Romanian: "Grigore"}},
	&Name{English, spellings{English: "Gunter", German: "Gunter", Dutch: "Gunter", Latin: "Gunterus", French: "", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Guy", German: "Guido", Dutch: "Guido", Latin: "Guido", French: "Guy", Italian: "Guido", Spanish: "Guido", Catalan: "", Portuguese: "Guido", Romanian: ""}},
	&Name{English, spellings{English: "Gustave", German: "Gustav", Dutch: "Gustaaf", Latin: "Gustavus", French: "Gustave", Italian: "Gustavo", Spanish: "Gustau", Catalan: "Gustavo", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Hank", German: "Heinz", Dutch: "Henk", Latin: "", French: "Riri", Italian: "Enzo", Spanish: "Enzo", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Harold", German: "Harald", Dutch: "Harold", Latin: "", French: "Harold", Italian: "Aroldo", Spanish: "", Catalan: "", Portuguese: "Haroldo", Romanian: ""}},
	&Name{English, spellings{English: "Henry", German: "Heinrich", Dutch: "Hendrik", Latin: "Henricus", French: "Henri", Italian: "Enrico", Spanish: "Enrique", Catalan: "Enric", Portuguese: "Henrique", Romanian: ""}},
	&Name{English, spellings{English: "Herbert", German: "Herbert", Dutch: "Herbert", Latin: "Heribertus", French: "Herbert", Italian: "Eriberto", Spanish: "Heriberto", Catalan: "Eribert", Portuguese: "Heriberto", Romanian: ""}},
	&Name{English, spellings{English: "Herman", German: "Hermann", Dutch: "Herman", Latin: "Armandus", French: "Armand", Italian: "Ermanno", Spanish: "Germán", Catalan: "", Portuguese: "Germano", Romanian: ""}},
	&Name{English, spellings{English: "Hilary", German: "Hilarius", Dutch: "Hilarius", Latin: "Hilarius", French: "Hilaire", Italian: "Ilario", Spanish: "Hilario", Catalan: "Hilari", Portuguese: "Hilário", Romanian: "Ilarie"}},
	&Name{English, spellings{English: "Hilary", German: "Hilarius", Dutch: "Hilarius", Latin: "Hilarius", French: "Hilaire", Italian: "Ilarione", Spanish: "Hilarión", Catalan: "", Portuguese: "Hilário", Romanian: "Ilarion"}},
	&Name{English, spellings{English: "Hippolytus", German: "", Dutch: "Hippoliet", Latin: "Hippolytus", French: "Hippolyte", Italian: "Ippolito", Spanish: "Hipólito", Catalan: "Hipòlit", Portuguese: "Hipólito", Romanian: ""}},
	&Name{English, spellings{English: "Horace", German: "Horaz", Dutch: "Horatius", Latin: "Horatius", French: "Horace", Italian: "Orazio", Spanish: "Horacio", Catalan: "Horaci", Portuguese: "Horácio", Romanian: "Horaţiu"}},
	&Name{English, spellings{English: "Hubert", German: "Hubert", Dutch: "Hubert", Latin: "Hubertus", French: "Hubert", Italian: "Uberto", Spanish: "Huberto", Catalan: "", Portuguese: "Huberto", Romanian: ""}},
	&Name{English, spellings{English: "Hugh", German: "Hugo", Dutch: "Hugo", Latin: "Hugonis", French: "Hugues", Italian: "Ugo", Spanish: "Hugo", Catalan: "", Portuguese: "Hugo", Romanian: ""}},
	&Name{English, spellings{English: "Ignatius", German: "Ignaz", Dutch: "Ignaat", Latin: "Ignatius", French: "Ignace", Italian: "Ignazio", Spanish: "Ignacio", Catalan: "Ignasi", Portuguese: "Inácio", Romanian: "Ignat"}},
	&Name{English, spellings{English: "Igor", German: "Igor", Dutch: "Igor", Latin: "Igor", French: "Igor", Italian: "Igor", Spanish: "", Catalan: "Ígor", Portuguese: "Igor", Romanian: ""}},
	&Name{English, spellings{English: "Innocent", German: "Innozenz", Dutch: "Innocent", Latin: "Innocentius", French: "Innocent", Italian: "Innocenzo", Spanish: "Inocencio", Catalan: "Inocenci", Portuguese: "Inocêncio", Romanian: ""}},
	&Name{English, spellings{English: "Isaac", German: "Isaak", Dutch: "Izaäk", Latin: "Isachus", French: "Isaac", Italian: "Isacco", Spanish: "Isaac", Catalan: "Isaac", Portuguese: "Isaac", Romanian: "Isac"}},
	&Name{English, spellings{English: "Isaiah", German: "Isah", Dutch: "Jesaja", Latin: "", French: "Isaïe", Italian: "Isaia", Spanish: "Isaías", Catalan: "", Portuguese: "Isaías", Romanian: "Isaia"}},
	&Name{English, spellings{English: "Isidore", German: "Isidor", Dutch: "Isidoor", Latin: "Isidorus", French: "Isidore", Italian: "Isidoro", Spanish: "Isidoro", Catalan: "Isidor", Portuguese: "Isidoro", Romanian: "Izidor"}},
	&Name{English, spellings{English: "James", German: "Jakob", Dutch: "Jakob", Latin: "Iacobus", French: "Jacques", Italian: "Giacomo", Spanish: "Jaime", Catalan: "Jaume", Portuguese: "Jaime", Romanian: "Iacob"}},
	&Name{English, spellings{English: "Jeremy", German: "Jeremiah", Dutch: "Jeremias", Latin: "Ieremias", French: "Jérémy", Italian: "Geremia", Spanish: "Jeremías", Catalan: "", Portuguese: "Jeremias", Romanian: "Eremia"}},
	&Name{English, spellings{English: "Jerome", German: "Hieronymus", Dutch: "Jeroen", Latin: "Hieronymus", French: "Jérôme", Italian: "Geronimo", Spanish: "Jerónimo", Catalan: "Jeroni", Portuguese: "Jerónimo", Romanian: "Eremia"}},
	&Name{English, spellings{English: "Joachim", German: "Joachim", Dutch: "Joachim", Latin: "Ioachim", French: "Joachim", Italian: "Gioacchino", Spanish: "Joaquín", Catalan: "Joaquim", Portuguese: "Joaquim", Romanian: "Ichim"}},
	&Name{English, spellings{English: "John", German: "Johann", Dutch: "Jan", Latin: "Ioannes", French: "Jean", Italian: "Giovanni", Spanish: "Juan", Catalan: "Joan", Portuguese: "João", Romanian: "Ion"}},
	&Name{English, spellings{English: "Jonathan", German: "Jonatan", Dutch: "Jonathan", Latin: "Ionathan", French: "Jonathan", Italian: "", Spanish: "Jonathan", Catalan: "", Portuguese: "Jónatas", Romanian: "Ionathan"}},
	&Name{English, spellings{English: "Joseph", German: "Josef", Dutch: "Jozef", Latin: "Iosephus", French: "Joseph", Italian: "Giuseppe", Spanish: "José", Catalan: "Josep", Portuguese: "José", Romanian: "Iosif"}},
	&Name{English, spellings{English: "Joshua", German: "Josua", Dutch: "Jozue", Latin: "Josue", French: "Josué", Italian: "Giosué", Spanish: "Josué", Catalan: "", Portuguese: "Josué", Romanian: ""}},
	&Name{English, spellings{English: "Julian", German: "Julian", Dutch: "Juliaan", Latin: "Iulianus", French: "Julien", Italian: "Giuliano", Spanish: "Julián", Catalan: "Julià", Portuguese: "Juliano", Romanian: "Iulian"}},
	&Name{English, spellings{English: "Julius", German: "Julius", Dutch: "Julius", Latin: "Iulius", French: "Jules", Italian: "Giulio", Spanish: "Julio", Catalan: "Juli", Portuguese: "Júlio", Romanian: "Julius"}},
	&Name{English, spellings{English: "Justin", German: "Justin", Dutch: "Justin", Latin: "Iustinus", French: "Justin", Italian: "Giustino", Spanish: "Justino", Catalan: "Justí", Portuguese: "Justino", Romanian: "Iustin"}},
	&Name{English, spellings{English: "Calistratus", German: "", Dutch: "", Latin: "Calistratus", French: "", Italian: "Callistrato", Spanish: "Calístrato", Catalan: "", Portuguese: "Calístrato", Romanian: "Calistrat"}},
	&Name{English, spellings{English: "Kevin", German: "Kevin", Dutch: "Kévin", Latin: "", French: "", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Lawrence", German: "Lorenz", Dutch: "Laurens", Latin: "Laurentius", French: "Laurent", Italian: "Lorenzo", Spanish: "Lorenzo", Catalan: "", Portuguese: "Lourenço", Romanian: "Laurenţiu"}},
	&Name{English, spellings{English: "Lazarus", German: "Lazar", Dutch: "Lazarus", Latin: "Lazarus", French: "Lazare", Italian: "Lazzaro", Spanish: "Lázaro", Catalan: "", Portuguese: "Lázaro", Romanian: "Lazǎr"}},
	&Name{English, spellings{English: "Leo", German: "Leon", Dutch: "Leo", Latin: "Léon", French: "Leo", Italian: "Leo", Spanish: "León", Catalan: "", Portuguese: "Leão", Romanian: "Leon"}},
	&Name{English, spellings{English: "Leonard", German: "Leonhard", Dutch: "Leonard", Latin: "Leonardus", French: "Léonard", Italian: "Leonardo", Spanish: "Leonardo", Catalan: "", Portuguese: "Leonardo", Romanian: ""}},
	&Name{English, spellings{English: "Leonide", German: "Leonid", Dutch: "Leonidas", Latin: "Leonidas", French: "Leonide", Italian: "Leonida", Spanish: "Leónidas", Catalan: "", Portuguese: "Leónidas", Romanian: "Leonida"}},
	&Name{English, spellings{English: "Leopold", German: "Leopold", Dutch: "Leopold", Latin: "Leopoldus", French: "Léopold", Italian: "Leopoldo", Spanish: "", Catalan: "Leopoldo", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Lionel", German: "Leonel", Dutch: "Lionel", Latin: "", French: "Lionel", Italian: "Lionello", Spanish: "Lionel", Catalan: "", Portuguese: "Leonel", Romanian: ""}},
	&Name{English, spellings{English: "Lewis", German: "Ludwig", Dutch: "Lodewijk", Latin: "Ludovicus", French: "Louis", Italian: "Luigi", Spanish: "Luis", Catalan: "", Portuguese: "Luís", Romanian: "Ludovic"}},
	&Name{English, spellings{English: "Luke", German: "Lukas", Dutch: "Lukas", Latin: "Lucas", French: "Luc", Italian: "Luca", Spanish: "Lucas", Catalan: "", Portuguese: "Lucas", Romanian: "Luca"}},
	&Name{English, spellings{English: "Lucianus", German: "Luzian", Dutch: "Lucien", Latin: "Lucianus", French: "Lucien", Italian: "Luciano", Spanish: "Luciano", Catalan: "", Portuguese: "Luciano", Romanian: "Lucian"}},
	&Name{English, spellings{English: "Magnus", German: "Magnus", Dutch: "Magnus", Latin: "Magnus", French: "", Italian: "Magno", Spanish: "Magno", Catalan: "", Portuguese: "Magno", Romanian: ""}},
	&Name{English, spellings{English: "Macarius", German: "Makarius", Dutch: "Macarius", Latin: "Macarius", French: "Macaire", Italian: "Macario", Spanish: "Macario", Catalan: "", Portuguese: "Macário", Romanian: "Macarie"}},
	&Name{English, spellings{English: "Mark", German: "Markus", Dutch: "Mark", Latin: "Marcus", French: "Marc", Italian: "Marco", Spanish: "Marcos", Catalan: "", Portuguese: "Marcos", Romanian: "Marcu"}},
	&Name{English, spellings{English: "Martin", German: "Martin", Dutch: "Maarten", Latin: "Martinus", French: "Martin", Italian: "Martino", Spanish: "Martín", Catalan: "", Portuguese: "Martim", Romanian: "Martin"}},
	&Name{English, spellings{English: "Matthew", German: "Matthäus", Dutch: "Mattheüs", Latin: "Matthaeus", French: "Matthieu", Italian: "Matteo", Spanish: "Mateo", Catalan: "Mateu", Portuguese: "Matei", Romanian: ""}},
	&Name{English, spellings{English: "Matthias", German: "Matthias", Dutch: "Matthias", Latin: "Matthaeus", French: "Matthias", Italian: "Mattia", Spanish: "Matías", Catalan: "", Portuguese: "Matias", Romanian: "Matei"}},
	&Name{English, spellings{English: "Maurice", German: "Moritz", Dutch: "Maurits", Latin: "Mauritius", French: "Maurice", Italian: "Maurizio", Spanish: "Mauricio", Catalan: "", Portuguese: "Maurício", Romanian: ""}},
	&Name{English, spellings{English: "Max", German: "Maxim", Dutch: "Maxime", Latin: "Maxime", French: "Maximus", Italian: "Massimo", Spanish: "", Catalan: "Máximo", Portuguese: "", Romanian: "Máximo"}},
	&Name{English, spellings{English: "Maximilian", German: "Maximilian", Dutch: "Maximiliaan", Latin: "Maximilianus", French: "Maximilien", Italian: "Massimiliano", Spanish: "Maximiliano", Catalan: "", Portuguese: "Maximilian", Romanian: ""}},
	&Name{English, spellings{English: "Michael", German: "Michael", Dutch: "Michaël", Latin: "Michael", French: "Michel", Italian: "Michele", Spanish: "Miguel", Catalan: "", Portuguese: "Miguel", Romanian: "Mihail"}},
	&Name{English, spellings{English: "Myron", German: "", Dutch: "Myron", Latin: "Myron", French: "", Italian: "Mirone", Spanish: "Mirón", Catalan: "", Portuguese: "Miron", Romanian: ""}},
	&Name{English, spellings{English: "Modestus", German: "", Dutch: "Modestus", Latin: "Modestus", French: "Modeste", Italian: "Modesto", Spanish: "Modesto", Catalan: "", Portuguese: "Modesto", Romanian: ""}},
	&Name{English, spellings{English: "Moses", German: "Moses", Dutch: "Mozes", Latin: "Moises", French: "Moïse", Italian: "Mosé", Spanish: "Moisés", Catalan: "", Portuguese: "Moisés", Romanian: "Moise"}},
	&Name{English, spellings{English: "Nathan", German: "Nathan", Dutch: "Nathan", Latin: "Nathan", French: "Nathan", Italian: "", Spanish: "", Catalan: "", Portuguese: "Natán", Romanian: ""}},
	&Name{English, spellings{English: "Nathaniel", German: "", Dutch: "Nathanaël", Latin: "", French: "Nathaniel", Italian: "Nataniele", Spanish: "Nataniel", Catalan: "", Portuguese: "Nataniel", Romanian: ""}},
	&Name{English, spellings{English: "Nazarius", German: "", Dutch: "Nazarius", Latin: "Nazarius", French: "Nazaire", Italian: "Nazario", Spanish: "Nazario", Catalan: "", Portuguese: "Nazário", Romanian: ""}},
	&Name{English, spellings{English: "Nestor", German: "Nestor", Dutch: "Nestor", Latin: "Nestor", French: "Nestor", Italian: "Nestore", Spanish: "Néstor", Catalan: "", Portuguese: "Nestor", Romanian: "Nestor"}},
	&Name{English, spellings{English: "Nicholas", German: "Nikolaus", Dutch: "Nicolaas", Latin: "Nicolaus", French: "Nicolas", Italian: "Nicola", Spanish: "Nicolás", Catalan: "", Portuguese: "Nicolau", Romanian: "Nicolae"}},
	&Name{English, spellings{English: "Nicodemus", German: "Nikodemus", Dutch: "Nicodemus", Latin: "Nicodemus", French: "Nicodème", Italian: "Nicodemo", Spanish: "Nicodemo", Catalan: "", Portuguese: "Nicodemo", Romanian: "Nicodim"}},
	&Name{English, spellings{English: "Octavius", German: "Octavius", Dutch: "Octaaf", Latin: "Octavius", French: "Octave", Italian: "Ottavio", Spanish: "Octavio", Catalan: "", Portuguese: "", Romanian: "Octavian"}},
	&Name{English, spellings{English: "Olaf", German: "Olaf", Dutch: "Olaf", Latin: "Olaus", French: "Olaf", Italian: "Olao", Spanish: "", Catalan: "", Portuguese: "Olavo", Romanian: ""}},
	&Name{English, spellings{English: "Olgierdus", German: "Olgierd", Dutch: "Oleg", Latin: "Olgierdus", French: "Oleg", Italian: "Olegario", Spanish: "Olegario", Catalan: "", Portuguese: "Olegário", Romanian: "Oleg"}},
	&Name{English, spellings{English: "Oliver", German: "Oliver", Dutch: "Olivier", Latin: "", French: "Olivier", Italian: "Oliviero", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Onuphrius", German: "", Dutch: "", Latin: "Onuphrius", French: "", Italian: "Onofrio", Spanish: "Onofre", Catalan: "", Portuguese: "Onofre", Romanian: "Onofrei"}},
	&Name{English, spellings{English: "Orestes", German: "", Dutch: "", Latin: "Orestes", French: "Oreste", Italian: "Oreste", Spanish: "", Catalan: "Orestes", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Oscar", German: "Oskar", Dutch: "Oscar", Latin: "Ansgaris", French: "Oscar", Italian: "Oscar", Spanish: "Óscar", Catalan: "", Portuguese: "Óscar", Romanian: ""}},
	&Name{English, spellings{English: "Osmund", German: "Osmond", Dutch: "Osmund", Latin: "", French: "Osmond", Italian: "Osmondo", Spanish: "Osmundo", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Pancras", German: "Pankraz", Dutch: "Pancras", Latin: "Pancratius", French: "Pancrace", Italian: "Pancrazio", Spanish: "Pancracio", Catalan: "", Portuguese: "Pancrácio", Romanian: ""}},
	&Name{English, spellings{English: "Pantaleon", German: "", Dutch: "Pantaleon", Latin: "Pantaleon", French: "Pantaléon", Italian: "Pantaleone", Spanish: "Pantaleón", Catalan: "", Portuguese: "Pantaleão", Romanian: ""}},
	&Name{English, spellings{English: "Patrick", German: "Patrick", Dutch: "Patrick", Latin: "Patricius", French: "Patrice", Italian: "Patrizio", Spanish: "Patricio", Catalan: "", Portuguese: "Patrício", Romanian: ""}},
	&Name{English, spellings{English: "Paul", German: "Paul", Dutch: "Paul", Latin: "Paulus", French: "Paul", Italian: "Paolo", Spanish: "Pablo", Catalan: "", Portuguese: "Paulo", Romanian: "Pavel"}},
	&Name{English, spellings{English: "Peter", German: "Peter", Dutch: "Pieter", Latin: "Petrus", French: "Pierre", Italian: "Pietro", Spanish: "Pedro", Catalan: "", Portuguese: "Pedro", Romanian: "Petre"}},
	&Name{English, spellings{English: "Philemon", German: "", Dutch: "Filemon", Latin: "", French: "Philémon", Italian: "Filemone", Spanish: "Filemón", Catalan: "", Portuguese: "", Romanian: "Filimon"}},
	&Name{English, spellings{English: "Phillip", German: "Philipp", Dutch: "Filip", Latin: "Philippus", French: "Philippe", Italian: "Filippo", Spanish: "Felipe", Catalan: "", Portuguese: "Filipe", Romanian: "Filip"}},
	&Name{English, spellings{English: "Plato", German: "Plato", Dutch: "Plato", Latin: "Plato", French: "Platon", Italian: "Platone", Spanish: "Platón", Catalan: "", Portuguese: "Platão", Romanian: "Platon"}},
	&Name{English, spellings{English: "Polycarpus", German: "", Dutch: "Polycarpus", Latin: "Polycarpus", French: "Polycarpe", Italian: "Policarpo", Spanish: "Policarpo", Catalan: "", Portuguese: "Policarpo", Romanian: ""}},
	&Name{English, spellings{English: "Porphyrius", German: "", Dutch: "Porfyrius", Latin: "Porphyrius", French: "Porphyre", Italian: "Porfirio", Spanish: "Porfirio", Catalan: "", Portuguese: "Porfírio", Romanian: ""}},
	&Name{English, spellings{English: "Proclus", German: "", Dutch: "", Latin: "Proclus", French: "", Italian: "Proclo", Spanish: "Proculo", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Procopius", German: "Prokopius", Dutch: "Procopius", Latin: "Procopius", French: "Procope", Italian: "Procopio", Spanish: "Procopio", Catalan: "", Portuguese: "Procópio", Romanian: "Procopie"}},
	&Name{English, spellings{English: "Quentin", German: "Quentin", Dutch: "Quinten", Latin: "Quintinus", French: "Quentin", Italian: "Quintino", Spanish: "Quintín", Catalan: "", Portuguese: "Quintino", Romanian: ""}},
	&Name{English, spellings{English: "Randolph", German: "Randolf", Dutch: "Randolf", Latin: "", French: "Raoul", Italian: "Randolfo", Spanish: "Randolfo", Catalan: "", Portuguese: "Randolfo", Romanian: ""}},
	&Name{English, spellings{English: "Raphael", German: "Raphael", Dutch: "Rafaël", Latin: "Raphael", French: "Raphaël", Italian: "Raffaele", Spanish: "Rafael", Catalan: "", Portuguese: "Rafael", Romanian: ""}},
	&Name{English, spellings{English: "Raymond", German: "Raimund", Dutch: "Raimond", Latin: "Raimundus", French: "Raymond", Italian: "Raimondo", Spanish: "Ramón", Catalan: "", Portuguese: "Raimundo", Romanian: ""}},
	&Name{English, spellings{English: "Reginald", German: "Reginald", Dutch: "Reginald", Latin: "Reginaldus", French: "Réginald", Italian: "Reginaldo", Spanish: "Reginaldo", Catalan: "", Portuguese: "Reginaldo", Romanian: ""}},
	&Name{English, spellings{English: "Reynold", German: "Reinhold", Dutch: "Reinout", Latin: "", French: "Renaud", Italian: "Reginaldo", Spanish: "Reinaldo", Catalan: "", Portuguese: "Reinaldo", Romanian: ""}},
	&Name{English, spellings{English: "Richard", German: "Richard", Dutch: "Richard", Latin: "Ricardus", French: "Richard", Italian: "Riccardo", Spanish: "Ricardo", Catalan: "", Portuguese: "Ricardo", Romanian: ""}},
	&Name{English, spellings{English: "Robert", German: "Robert", Dutch: "Robert", Latin: "Robertus", French: "Robert", Italian: "Roberto", Spanish: "Roberto", Catalan: "", Portuguese: "Roberto", Romanian: ""}},
	&Name{English, spellings{English: "Roderick", German: "Roderich", Dutch: "Roderik", Latin: "Rodericus", French: "Rodrigue", Italian: "Rodrigo", Spanish: "Rodrigo", Catalan: "", Portuguese: "Rodrigo", Romanian: ""}},
	&Name{English, spellings{English: "Roger", German: "Rüdiger", Dutch: "Rutger", Latin: "", French: "Roger", Italian: "Ruggero", Spanish: "Rogelio", Catalan: "", Portuguese: "Rogério", Romanian: ""}},
	&Name{English, spellings{English: "Roland", German: "Roland", Dutch: "Roland", Latin: "Rolandus", French: "Roland", Italian: "Rolando", Spanish: "Rolando", Catalan: "", Portuguese: "Rolando", Romanian: "Roland"}},
	&Name{English, spellings{English: "Roman", German: "Roman", Dutch: "Romanus", Latin: "Romanus", French: "Romain", Italian: "Romano", Spanish: "Román", Catalan: "", Portuguese: "Romão", Romanian: "Roman"}},
	&Name{English, spellings{English: "Romeo", German: "Romeo", Dutch: "Romeo", Latin: "", French: "Roméo", Italian: "Romeo", Spanish: "Romeo", Catalan: "", Portuguese: "Romeu", Romanian: ""}},
	&Name{English, spellings{English: "Ronald", German: "Ronald", Dutch: "Ronald", Latin: "", French: "Ronald", Italian: "Ronaldo", Spanish: "Ronaldo", Catalan: "", Portuguese: "Ronaldo", Romanian: ""}},
	&Name{English, spellings{English: "Rudolph", German: "Rudolf", Dutch: "Rudolf", Latin: "Rudolphus", French: "Rodolphe", Italian: "Rodolfo", Spanish: "Rodolfo", Catalan: "", Portuguese: "Rodolfo", Romanian: ""}},
	&Name{English, spellings{English: "Samson", German: "Samson", Dutch: "Samson", Latin: "", French: "Samson", Italian: "Sansone", Spanish: "Sansón", Catalan: "Sansão", Portuguese: "Samson", Romanian: ""}},
	&Name{English, spellings{English: "Samuel", German: "Samuel", Dutch: "Samuël", Latin: "Samuel", French: "Samuel", Italian: "Samuele", Spanish: "Samuel", Catalan: "", Portuguese: "Samuel", Romanian: "Samuil"}},
	&Name{English, spellings{English: "Salvator", German: "", Dutch: "", Latin: "Salvator", French: "Sauveur", Italian: "Salvatore", Spanish: "Salvador", Catalan: "", Portuguese: "Salvador", Romanian: ""}},
	&Name{English, spellings{English: "Sebastian", German: "Sebastian", Dutch: "Sebastiaan", Latin: "Sebastianus", French: "Sébastien", Italian: "Sebastiano", Spanish: "Sebastián", Catalan: "", Portuguese: "Sebastião", Romanian: "Sebastian"}},
	&Name{English, spellings{English: "Seraph", German: "Seraphim", Dutch: "Serafin", Latin: "Seraphinus", French: "Séraphin", Italian: "Serafino", Spanish: "Serafín", Catalan: "", Portuguese: "Serafim", Romanian: "Serafim"}},
	&Name{English, spellings{English: "Serge", German: "Serge", Dutch: "Serge", Latin: "Sergius", French: "Serge", Italian: "Sergio", Spanish: "Sergio", Catalan: "", Portuguese: "Sérgio", Romanian: ""}},
	&Name{English, spellings{English: "Severin", German: "Severin", Dutch: "Severijn", Latin: "Severinus", French: "Sévère", Italian: "Severo", Spanish: "Severo", Catalan: "Severino", Portuguese: "Sever", Romanian: ""}},
	&Name{English, spellings{English: "Sigmund", German: "Siegmund", Dutch: "Siegmund", Latin: "", French: "Sigismond", Italian: "Sigismondo", Spanish: "Segismundo", Catalan: "Sigismundo", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Sylvester", German: "Silvester", Dutch: "Silvester", Latin: "Silvester", French: "Sylvestre", Italian: "Silvestro", Spanish: "Silvestre", Catalan: "", Portuguese: "Silvestre", Romanian: "Silvester"}},
	&Name{English, spellings{English: "Simon", German: "Simon", Dutch: "Simon", Latin: "Simonis", French: "Simon", Italian: "Simone", Spanish: "Simón", Catalan: "", Portuguese: "Simão", Romanian: "Simion"}},
	&Name{English, spellings{English: "Solomon", German: "Salomon", Dutch: "Salomon", Latin: "Salomo", French: "Salomon", Italian: "Salomone", Spanish: "Salomón", Catalan: "", Portuguese: "Salomão", Romanian: "Solomon"}},
	&Name{English, spellings{English: "Spyridon", German: "", Dutch: "Spiridon", Latin: "Spyridon", French: "Spiridione", Italian: "Spiridione", Spanish: "Espiridión", Catalan: "Espiridião", Portuguese: "Spiridon", Romanian: ""}},
	&Name{English, spellings{English: "Stanley", German: "Stanislaus", Dutch: "Stanley", Latin: "Stanislaus", French: "Stanislas", Italian: "Stanislao", Spanish: "Estanislao", Catalan: "", Portuguese: "Estanislau", Romanian: ""}},
	&Name{English, spellings{English: "Steven", German: "Stephan", Dutch: "Stefan", Latin: "Stephanus", French: "Étienne", Italian: "Stefano", Spanish: "Esteban", Catalan: "", Portuguese: "Estêvão", Romanian: "Ştefan"}},
	&Name{English, spellings{English: "Taras", German: "Tarus", Dutch: "", Latin: "Taras", French: "", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Terence", German: "", Dutch: "", Latin: "Terentius", French: "Térence", Italian: "Terenzio", Spanish: "Terencio", Catalan: "", Portuguese: "Terêncio", Romanian: ""}},
	&Name{English, spellings{English: "Theodore", German: "Theodor", Dutch: "Theodoor", Latin: "Theodorus", French: "Théodore", Italian: "Teodoro", Spanish: "Teodoro", Catalan: "", Portuguese: "Teodoro", Romanian: "Tudor"}},
	&Name{English, spellings{English: "Thomas", German: "Thomas", Dutch: "Thomas", Latin: "Thomas", French: "Thomas", Italian: "Tommaso", Spanish: "Tomás", Catalan: "", Portuguese: "Tomás", Romanian: "Toma"}},
	&Name{English, spellings{English: "Tiberius", German: "", Dutch: "", Latin: "Tiberius", French: "Tibère", Italian: "Tiberio", Spanish: "", Catalan: "", Portuguese: "", Romanian: "Tiberiu"}},
	&Name{English, spellings{English: "Timothy", German: "Timotheus", Dutch: "Timotheüs", Latin: "Timotheus", French: "Timothée", Italian: "Timoteo", Spanish: "Timoteo", Catalan: "", Portuguese: "Timóteo", Romanian: ""}},
	&Name{English, spellings{English: "Toby", German: "Tobias", Dutch: "Tobias", Latin: "Tobias", French: "Tobie", Italian: "Tobia", Spanish: "Tobías", Catalan: "", Portuguese: "Tobias", Romanian: ""}},
	&Name{English, spellings{English: "Urban", German: "Urban", Dutch: "Urbaan", Latin: "Urbanus", French: "Urbain", Italian: "Urbano", Spanish: "Urbano", Catalan: "", Portuguese: "Urbano", Romanian: "Urban"}},
	&Name{English, spellings{English: "Ulric", German: "Ulrich", Dutch: "Ulrik", Latin: "Ulricus", French: "Ulric", Italian: "Ulrico", Spanish: "Ulrico", Catalan: "", Portuguese: "Ulrico", Romanian: "Ulric"}},
	&Name{English, spellings{English: "Uriah", German: "Urias", Dutch: "Urias", Latin: "Urias", French: "Uria", Italian: "Urias", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Uriel", German: "Uriel", Dutch: "Uriël", Latin: "Ulriel", French: "Uriël", Italian: "Uriele", Spanish: "Uriel", Catalan: "", Portuguese: "Uriel", Romanian: ""}},
	&Name{English, spellings{English: "Ursus", German: "Urs", Dutch: "Ursus", Latin: "Ursus", French: "Urs", Italian: "Orsino", Spanish: "Urso", Catalan: "", Portuguese: "Urso", Romanian: ""}},
	&Name{English, spellings{English: "Valentine", German: "Valentin", Dutch: "Valentijn", Latin: "Valentinus", French: "Valentin", Italian: "Valentino", Spanish: "Valentín", Catalan: "", Portuguese: "Valentim", Romanian: "Valentin"}},
	&Name{English, spellings{English: "Valerian", German: "Valerian", Dutch: "Valeriaan", Latin: "Valerianus", French: "Valérien", Italian: "Valeriano", Spanish: "Valeriano", Catalan: "", Portuguese: "Valeriano", Romanian: ""}},
	&Name{English, spellings{English: "Valerius", German: "Valerius", Dutch: "Valerius", Latin: "Valerius", French: "Valéry", Italian: "Valerio", Spanish: "Valerio", Catalan: "", Portuguese: "Valério", Romanian: "Valer"}},
	&Name{English, spellings{English: "Victor", German: "Viktor", Dutch: "Victor", Latin: "Victor", French: "Victor", Italian: "Vittorio", Spanish: "Víctor", Catalan: "", Portuguese: "Victor", Romanian: "Victor"}},
	&Name{English, spellings{English: "Vincent", German: "Vinzenz", Dutch: "Vincent", Latin: "Vincentius", French: "Vincent", Italian: "Vincenzo", Spanish: "Vicente", Catalan: "", Portuguese: "Vicente", Romanian: "Vincenţiu"}},
	&Name{English, spellings{English: "Vital", German: "", Dutch: "Vitalis", Latin: "Vital", French: "Vitalis", Italian: "Vitale", Spanish: "Vidal", Catalan: "", Portuguese: "Vital", Romanian: ""}},
	&Name{English, spellings{English: "Valdemar", German: "Waldemar", Dutch: "Waldemar", Latin: "Valdemar", French: "", Italian: "Valdemaro", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "William", German: "Wilhelm", Dutch: "Wilhelm", Latin: "Gulielmus", French: "Guillaume", Italian: "Guglielmo", Spanish: "Guillermo", Catalan: "", Portuguese: "Guilherme", Romanian: ""}},
	&Name{English, spellings{English: "Vladimir", German: "Wladimir", Dutch: "Wladimir", Latin: "", French: "Wladimir", Italian: "Vladimiro", Spanish: "", Catalan: "Vladimiro", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Vladislav", German: "Ladislaus", Dutch: "Ladislaus", Latin: "Ladislaus", French: "Ladislas", Italian: "Ladislao", Spanish: "Ladislao", Catalan: "", Portuguese: "Ladislau", Romanian: ""}},
	&Name{English, spellings{English: "Walter", German: "Walther", Dutch: "Walter", Latin: "Gualterius", French: "Gautier", Italian: "Gualtiero", Spanish: "Gualterio", Catalan: "", Portuguese: "Válter", Romanian: ""}},
	&Name{English, spellings{English: "Wenceslas", German: "Wenzel", Dutch: "Wenceslaus", Latin: "Wenceslaus", French: "Wenceslas", Italian: "Venceslao", Spanish: "Wenceslao", Catalan: "", Portuguese: "Venceslau", Romanian: ""}},
	&Name{English, spellings{English: "Wilfred", German: "Wilfried", Dutch: "Wilfred", Latin: "", French: "", Italian: "Vilfrido", Spanish: "Wilfredo", Catalan: "Vilfredo", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "William", German: "Wilhelm", Dutch: "Wilhelm", Latin: "Gulielmus", French: "Guillaume", Italian: "Guglielmo", Spanish: "Guillermo", Catalan: "", Portuguese: "Guilhermo", Romanian: "Gulielm"}},
	&Name{English, spellings{English: "Xavier", German: "Xaver", Dutch: "Xavier", Latin: "Xaverius", French: "Xavier", Italian: "Saverio", Spanish: "Javier", Catalan: "", Portuguese: "Xavier", Romanian: ""}},
	&Name{English, spellings{English: "Xenophon", German: "", Dutch: "Xenophon", Latin: "Xenophon", French: "Xénophon", Italian: "Senofonte", Spanish: "Jenofonte", Catalan: "", Portuguese: "Xenofonte", Romanian: ""}},
	&Name{English, spellings{English: "Zachary", German: "Zacharias", Dutch: "Zacharias", Latin: "Zacharias", French: "Zacharie", Italian: "Zaccaria", Spanish: "Zacarías", Catalan: "", Portuguese: "Zacarias", Romanian: "Zaharie"}},
	&Name{English, spellings{English: "Abigail", German: "Abigail", Dutch: "Abigaïl", Latin: "Abigail", French: "Abigail", Italian: "", Spanish: "Abigail", Catalan: "Abigail", Portuguese: "Abigail", Romanian: ""}},
	&Name{English, spellings{English: "Ada", German: "Ada", Dutch: "Ada", Latin: "", French: "Ada", Italian: "Ada", Spanish: "Ada", Catalan: "Ada", Portuguese: "Ada", Romanian: "Ada"}},
	&Name{English, spellings{English: "Adela", German: "Adele", Dutch: "Adèle", Latin: "", French: "Adèle", Italian: "Adele", Spanish: "Adela", Catalan: "Adela", Portuguese: "Adélia", Romanian: "Adela"}},
	&Name{English, spellings{English: "Adelaide", German: "Adelheid", Dutch: "Adelheid", Latin: "", French: "Adélaïde", Italian: "Adelaide", Spanish: "Adelaida", Catalan: "Adelaida", Portuguese: "Adelaide", Romanian: ""}},
	&Name{English, spellings{English: "Adriana", German: "Adriane", Dutch: "Adriana", Latin: "Adriana", French: "Adrienne", Italian: "Adriana", Spanish: "Adriana", Catalan: "Adriana", Portuguese: "Adriana", Romanian: "Adriana"}},
	&Name{English, spellings{English: "Agatha", German: "Agatha", Dutch: "Agatha", Latin: "Agatha", French: "Agathe", Italian: "Agata", Spanish: "Ágata", Catalan: "Àgata", Portuguese: "Ágata", Romanian: ""}},
	&Name{English, spellings{English: "Aglaia", German: "Aglaia", Dutch: "Aglaia", Latin: "Aglaia", French: "Aglaïe", Italian: "Aglaia", Spanish: "Aglaya", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Agnes", German: "Agnes", Dutch: "Agnes", Latin: "Agnes", French: "Agnès", Italian: "Agnese", Spanish: "Inés", Catalan: "Agnès", Portuguese: "Inês", Romanian: ""}},
	&Name{English, spellings{English: "Agrippina", German: "Agrippina", Dutch: "Agripinna", Latin: "Agrippina", French: "Agrippine", Italian: "Agrippina", Spanish: "Agripina", Catalan: "Agripina", Portuguese: "Agripina", Romanian: "Agripina"}},
	&Name{English, spellings{English: "Aida", German: "Aida", Dutch: "Aïda", Latin: "", French: "Aïde", Italian: "Aida", Spanish: "Aida", Catalan: "Aida", Portuguese: "Aida", Romanian: "Aida"}},
	&Name{English, spellings{English: "Alba", German: "", Dutch: "Alba", Latin: "Alba", French: "", Italian: "Alba", Spanish: "Alba", Catalan: "Alba", Portuguese: "Alba", Romanian: ""}},
	&Name{English, spellings{English: "Albana", German: "Albana", Dutch: "Albana", Latin: "Albana", French: "Albane", Italian: "Albana", Spanish: "Albana", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Alberta", German: "Alberta", Dutch: "Albertine", Latin: "", French: "Albertine", Italian: "Alberta", Spanish: "Albertina", Catalan: "", Portuguese: "Alberta", Romanian: ""}},
	&Name{English, spellings{English: "Albina", German: "Albina", Dutch: "Albina", Latin: "Albina", French: "Albina", Italian: "Albina", Spanish: "Albina", Catalan: "Albina", Portuguese: "Albina", Romanian: ""}},
	&Name{English, spellings{English: "Alda", German: "Alda", Dutch: "Alda", Latin: "", French: "Aude", Italian: "Alda", Spanish: "Alda", Catalan: "Alda", Portuguese: "Alda", Romanian: ""}},
	&Name{English, spellings{English: "Alexandra", German: "Alexandra", Dutch: "Alexandra", Latin: "Alexandra", French: "Alexandra", Italian: "Alessandra", Spanish: "Alejandra", Catalan: "Alexandra", Portuguese: "Alexandra", Romanian: "Alexandra"}},
	&Name{English, spellings{English: "Alexia", German: "Alexia", Dutch: "Alexia", Latin: "Alexia", French: "Alexia", Italian: "Alessia", Spanish: "Alexia", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Alphonsina", German: "Alfonse", Dutch: "Alfonsine", Latin: "", French: "Alphonsine", Italian: "Alfonsina", Spanish: "Alfonsa", Catalan: "Alfonsa", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Alfreda", German: "Alfreda", Dutch: "Alfreda", Latin: "", French: "", Italian: "Alfreda", Spanish: "Alfreda", Catalan: "Alfreda", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Alice", German: "Alice", Dutch: "Alice", Latin: "Alicia", French: "Alice", Italian: "Alice", Spanish: "Alicia", Catalan: "Alícia", Portuguese: "Alice", Romanian: "Alice"}},
	&Name{English, spellings{English: "Alida", German: "Alida", Dutch: "Alida", Latin: "", French: "", Italian: "Alida", Spanish: "Alida", Catalan: "Alida", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Alina", German: "Alina", Dutch: "Alina", Latin: "", French: "Aline", Italian: "Alina", Spanish: "Alina", Catalan: "Alina", Portuguese: "Alina", Romanian: "Alina"}},
	&Name{English, spellings{English: "Alma", German: "Alma", Dutch: "Alma", Latin: "Alma", French: "Alma", Italian: "Alma", Spanish: "Alma", Catalan: "Alma", Portuguese: "Alma", Romanian: "Alma"}},
	&Name{English, spellings{English: "Althea", German: "", Dutch: "Althea", Latin: "Althea", French: "Althéa", Italian: "Altea", Spanish: "Altea", Catalan: "", Portuguese: "Alteia", Romanian: ""}},
	&Name{English, spellings{English: "Amelia", German: "Amalie", Dutch: "Amalia", Latin: "Amalia", French: "Amélie", Italian: "Amalia", Spanish: "Amalia", Catalan: "Amàlia", Portuguese: "Amália", Romanian: ""}},
	&Name{English, spellings{English: "Amanda", German: "Amanda", Dutch: "Amanda", Latin: "Amanda", French: "Amanda", Italian: "Amanda", Spanish: "Amanda", Catalan: "Amanda", Portuguese: "Amanda", Romanian: "Amanda"}},
	&Name{English, spellings{English: "Amy", German: "Amata", Dutch: "Amata", Latin: "Amata", French: "Aimée", Italian: "Amata", Spanish: "Amada", Catalan: "", Portuguese: "Amada", Romanian: ""}},
	&Name{English, spellings{English: "Anastasia", German: "Anastasia", Dutch: "Anastasia", Latin: "Anastasia", French: "Anastasie", Italian: "Anastasia", Spanish: "Anastasia", Catalan: "Anastàsia", Portuguese: "Anastácia", Romanian: "Anastasia"}},
	&Name{English, spellings{English: "Andrea", German: "Andrea", Dutch: "Andrea", Latin: "", French: "Andrée", Italian: "Andreina", Spanish: "Andrea", Catalan: "Andrea", Portuguese: "Andreia; Andréia", Romanian: "Andreea"}},
	&Name{English, spellings{English: "Andromache", German: "Andromache", Dutch: "Andromache", Latin: "Andromache", French: "Andromaque", Italian: "Andromaca", Spanish: "Andrómaca", Catalan: "Andròmaca", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Andromeda", German: "Andromeda", Dutch: "Andromeda", Latin: "Andromeda", French: "Andromède", Italian: "Andromeda", Spanish: "Andrómeda", Catalan: "Andromèda", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Angela", German: "Angela", Dutch: "Angela", Latin: "Angela", French: "Angèle", Italian: "Angela", Spanish: "Ángela", Catalan: "Àngela", Portuguese: "Ângela", Romanian: ""}},
	&Name{English, spellings{English: "Angelica", German: "Angelika", Dutch: "Angelique", Latin: "Angelica", French: "Angélique", Italian: "Angelica", Spanish: "Angélica", Catalan: "Angèlica", Portuguese: "Angélica", Romanian: ""}},
	&Name{English, spellings{English: "Angelina", German: "Angelina", Dutch: "Angeline", Latin: "Angelina", French: "Angéline", Italian: "Angelina", Spanish: "Angelina", Catalan: "Angelina", Portuguese: "Angelina", Romanian: "Anghelina"}},
	&Name{English, spellings{English: "Anita", German: "Anita", Dutch: "Anita", Latin: "", French: "", Italian: "Anita", Spanish: "Anita", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Ann", German: "Anna", Dutch: "Anna", Latin: "Anna", French: "Anne", Italian: "Anna", Spanish: "Ana", Catalan: "Anna", Portuguese: "Ana", Romanian: "Ana"}},
	&Name{English, spellings{English: "Annabel", German: "Annabel", Dutch: "Annabel", Latin: "", French: "Annabelle", Italian: "Annabella", Spanish: "Anabel", Catalan: "Annabel", Portuguese: "Anabela", Romanian: ""}},
	&Name{English, spellings{English: "Annette", German: "Annette", Dutch: "Annette", Latin: "", French: "", Italian: "Annetta", Spanish: "Anita", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Antigone", German: "Antigone", Dutch: "Antigone", Latin: "Antigone", French: "Antigone", Italian: "Antigone", Spanish: "Antígona", Catalan: "Antígona", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Antonia", German: "Antonia", Dutch: "Antonia", Latin: "Antonia", French: "Antoinette", Italian: "Antonia", Spanish: "Antonia", Catalan: "Antònia", Portuguese: "Antónia", Romanian: "Antoaneta"}},
	&Name{English, spellings{English: "Aphra", German: "", Dutch: "Afra", Latin: "Aphra", French: "", Italian: "Afra", Spanish: "Afra", Catalan: "Afra", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Aphrodite", German: "Aphrodite", Dutch: "Aphrodite", Latin: "Aphrodite", French: "Aphrodite", Italian: "Afrodite", Spanish: "Afrodita", Catalan: "Afrodita", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Apollonia", German: "Apollonie", Dutch: "Apollonia", Latin: "Apollonia", French: "Apolline", Italian: "Apollonia", Spanish: "Apolonia", Catalan: "Apollònia", Portuguese: "Apolónia", Romanian: ""}},
	&Name{English, spellings{English: "Aquillina", German: "", Dutch: "", Latin: "Aquillina", French: "", Italian: "Aquilina", Spanish: "Aquilina", Catalan: "Aquillina", Portuguese: "Aquilina", Romanian: ""}},
	&Name{English, spellings{English: "Arabella", German: "Arabella", Dutch: "Arabella", Latin: "", French: "", Italian: "Arabella", Spanish: "Arabela", Catalan: "Arabella", Portuguese: "Arabela", Romanian: ""}},
	&Name{English, spellings{English: "Ariadne", German: "Ariane", Dutch: "Ariadne", Latin: "Ariadne", French: "Ariane", Italian: "Arianna", Spanish: "Ariadna", Catalan: "Ariadna", Portuguese: "Ariana", Romanian: ""}},
	&Name{English, spellings{English: "Arlette", German: "", Dutch: "Arlette", Latin: "", French: "", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Artemis", German: "Artemis", Dutch: "Artemis", Latin: "Artemis", French: "", Italian: "Artemide", Spanish: "Atemisa", Catalan: "Artemis", Portuguese: "Artémis", Romanian: ""}},
	&Name{English, spellings{English: "Aspasia", German: "Aspasia", Dutch: "Aspasia", Latin: "Aspasia", French: "", Italian: "Aspasia", Spanish: "Aspasia", Catalan: "Aspàsia", Portuguese: "Aspásia", Romanian: ""}},
	&Name{English, spellings{English: "Astrid", German: "Astrid", Dutch: "Astrid", Latin: "", French: "Astrid", Italian: "Astrid", Spanish: "Astrid", Catalan: "Astrid", Portuguese: "Astrid", Romanian: ""}},
	&Name{English, spellings{English: "Atalante", German: "Atalante", Dutch: "Atalante", Latin: "Atalante", French: "Atalante", Italian: "Atlanta", Spanish: "Atalanta", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Athanasia", German: "Athanasie", Dutch: "Athanasia", Latin: "Athanasia", French: "", Italian: "Atanasia", Spanish: "Atanasia", Catalan: "Atànasia", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Augusta", German: "Augusta", Dutch: "Augusta", Latin: "Augusta", French: "Auguste", Italian: "Augusta", Spanish: "Augusta", Catalan: "Augusta", Portuguese: "Augusta", Romanian: ""}},
	&Name{English, spellings{English: "Augustina", German: "Augustine", Dutch: "Augustina", Latin: "Augustina", French: "Augustine", Italian: "Agostina", Spanish: "Agustina", Catalan: "Agustina", Portuguese: "Agostinha", Romanian: ""}},
	&Name{English, spellings{English: "Aurelia", German: "Aurelie", Dutch: "Aurelia", Latin: "Aurelia", French: "Aurélie", Italian: "Aurelia", Spanish: "Aurelia", Catalan: "Aurèlia", Portuguese: "Aurélia", Romanian: "Aurelia"}},
	&Name{English, spellings{English: "Aurora", German: "Aurora", Dutch: "Aurora", Latin: "Aurora", French: "Aurore", Italian: "Aurora", Spanish: "Aurora", Catalan: "Aurora", Portuguese: "Aurora", Romanian: "Aurora"}},
	&Name{English, spellings{English: "Balbina", German: "Balbina", Dutch: "", Latin: "Balbina", French: "Balbine", Italian: "Balbina", Spanish: "Balbina", Catalan: "Balbia", Portuguese: "Balbina", Romanian: ""}},
	&Name{English, spellings{English: "Barbara", German: "Barbara", Dutch: "Barbara", Latin: "Barbara", French: "Barbara", Italian: "Barbara", Spanish: "Bárbara", Catalan: "Bàrbara", Portuguese: "Bárbara", Romanian: ""}},
	&Name{English, spellings{English: "Beata", German: "Beate", Dutch: "Beate", Latin: "Beata", French: "Béate", Italian: "Beata", Spanish: "Beata", Catalan: "Beata", Portuguese: "Beata", Romanian: ""}},
	&Name{English, spellings{English: "Beatrice", German: "Beatrix", Dutch: "Beatrijs", Latin: "Beatrix", French: "Béatrice", Italian: "Beatrice", Spanish: "Beatriz", Catalan: "Beatriu", Portuguese: "Beatriz", Romanian: "Beatrice"}},
	&Name{English, spellings{English: "Bella", German: "Bella", Dutch: "Bella", Latin: "", French: "Belle", Italian: "Bella", Spanish: "", Catalan: "", Portuguese: "Bela", Romanian: ""}},
	&Name{English, spellings{English: "Benedicta", German: "Benedikte", Dutch: "Benedicta", Latin: "Benedicta", French: "Benoîte", Italian: "Benedetta", Spanish: "Benita", Catalan: "Beneta", Portuguese: "Benedita", Romanian: ""}},
	&Name{English, spellings{English: "Berenice", German: "Berenice", Dutch: "Berenice", Latin: "Berenice", French: "Bérénice", Italian: "Berenice", Spanish: "Berenice", Catalan: "Bereniç", Portuguese: "Berenice", Romanian: ""}},
	&Name{English, spellings{English: "Bernarda", German: "Bernharda", Dutch: "Bernarda", Latin: "", French: "Bernadette", Italian: "Bernarda", Spanish: "Bernarda", Catalan: "", Portuguese: "Bernarda", Romanian: ""}},
	&Name{English, spellings{English: "Bertha", German: "Bertha", Dutch: "Bertha", Latin: "", French: "Berthe", Italian: "Berta", Spanish: "Berta", Catalan: "Berta", Portuguese: "Berta", Romanian: ""}},
	&Name{English, spellings{English: "Bibiana", German: "Bibiane", Dutch: "Bibiana", Latin: "Bibiana", French: "Bibiane", Italian: "Bibiana", Spanish: "Bibiana", Catalan: "Bibiana", Portuguese: "Bibiana", Romanian: ""}},
	&Name{English, spellings{English: "Blanche", German: "Blanka", Dutch: "Blanca", Latin: "", French: "Blanche", Italian: "Bianca", Spanish: "Blanca", Catalan: "Blanca", Portuguese: "Branca", Romanian: "Bianca"}},
	&Name{English, spellings{English: "Brenda", German: "", Dutch: "Brenda", Latin: "", French: "", Italian: "", Spanish: "Brenda", Catalan: "Brenda", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Bridget", German: "Brigitte", Dutch: "Brigit", Latin: "Brigitta", French: "Brigitte", Italian: "Brigida", Spanish: "Brígida", Catalan: "Brígida", Portuguese: "Brígida", Romanian: ""}},
	&Name{English, spellings{English: "Brunhilde", German: "Brunhild", Dutch: "Brunhilde", Latin: "", French: "Brunehault", Italian: "Brunilde", Spanish: "Brunilda", Catalan: "Brunilda", Portuguese: "Bruna", Romanian: ""}},
	&Name{English, spellings{English: "Camilla", German: "Camilla", Dutch: "Camilla", Latin: "Camilla", French: "Camille", Italian: "Camilla", Spanish: "Camila", Catalan: "Camilla", Portuguese: "Camila", Romanian: "Camelia"}},
	&Name{English, spellings{English: "Carol", German: "Karola", Dutch: "Carola", Latin: "Carola", French: "Carole", Italian: "Carola", Spanish: "Carla", Catalan: "", Portuguese: "Carla", Romanian: "Carla"}},
	&Name{English, spellings{English: "Caroline", German: "Karoline", Dutch: "Caroline", Latin: "Carolina", French: "Caroline", Italian: "Carolina", Spanish: "Carolina", Catalan: "Carolina", Portuguese: "Carolina", Romanian: ""}},
	&Name{English, spellings{English: "Cassandra", German: "Kassandra", Dutch: "Cassandra", Latin: "Cassandra", French: "Cassandre", Italian: "Cassandra", Spanish: "Casandra", Catalan: "Cassandra", Portuguese: "Cassandra", Romanian: ""}},
	&Name{English, spellings{English: "Catherine", German: "Katarina", Dutch: "Catharina", Latin: "Catherina", French: "Catherine", Italian: "Caterina", Spanish: "Catalina", Catalan: "Caterina", Portuguese: "Catarina", Romanian: "Cătălina"}},
	&Name{English, spellings{English: "Cecilia", German: "Cecilie", Dutch: "Ceciel", Latin: "Caecilia", French: "Cécile", Italian: "Cecilia", Spanish: "Cecilia", Catalan: "Cecília", Portuguese: "Cecília", Romanian: "Cecilia"}},
	&Name{English, spellings{English: "Celeste", German: "", Dutch: "Celeste", Latin: "", French: "", Italian: "Celeste", Spanish: "", Catalan: "Celeste", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Charity", German: "Caritas", Dutch: "Caritas", Latin: "Caritas", French: "Charité", Italian: "", Spanish: "Caridad", Catalan: "Caritat", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Charlotte", German: "Charlotte", Dutch: "Charlotte", Latin: "Carola", French: "Charlotte", Italian: "Carlotta", Spanish: "Carlota", Catalan: "Carlota", Portuguese: "Carlota", Romanian: ""}},
	&Name{English, spellings{English: "Chloë", German: "Chloe", Dutch: "Chloë", Latin: "Chloe", French: "Chloé", Italian: "Cloe", Spanish: "Cloe", Catalan: "Cloe", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Christine", German: "Kristine", Dutch: "Christina", Latin: "Christina", French: "Christine", Italian: "Cristina", Spanish: "Cristina", Catalan: "Cristina", Portuguese: "Cristina", Romanian: "Cristina"}},
	&Name{English, spellings{English: "Clara", German: "Klara", Dutch: "Clara", Latin: "Clara", French: "Claire", Italian: "Chiara", Spanish: "Clara", Catalan: "Clara", Portuguese: "Clara", Romanian: "Clara"}},
	&Name{English, spellings{English: "Claudia", German: "Klaudia", Dutch: "Claudia", Latin: "Claudia", French: "Claude", Italian: "Claudia", Spanish: "Claudia", Catalan: "Clàudia", Portuguese: "Cláudia", Romanian: "Claudia"}},
	&Name{English, spellings{English: "Clemence", German: "", Dutch: "Clemence", Latin: "", French: "", Italian: "Clemenzia", Spanish: "", Catalan: "Clemência", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Clementine", German: "Klemenetine", Dutch: "Clementine", Latin: "Clementina", French: "Clémentine", Italian: "Clementina", Spanish: "Clementina", Catalan: "Clementina", Portuguese: "Clemência", Romanian: ""}},
	&Name{English, spellings{English: "Cleopatra", German: "Cleopatra", Dutch: "Cleopatra", Latin: "Cleopatra", French: "Cléopâtre", Italian: "Cleopatra", Spanish: "Cleopatra", Catalan: "Cleópatra", Portuguese: "Cléopatra", Romanian: ""}},
	&Name{English, spellings{English: "Clotilde", German: "", Dutch: "Clotilde", Latin: "", French: "", Italian: "Clotilde", Spanish: "", Catalan: "Clotilde", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Constance", German: "Konstanze", Dutch: "Constance", Latin: "Constantia", French: "Constance", Italian: "Costanza", Spanish: "Constancia", Catalan: "Constança", Portuguese: "Constança", Romanian: "Constanţa"}},
	&Name{English, spellings{English: "Coralie", German: "", Dutch: "Coralie", Latin: "", French: "Coralie", Italian: "Corallina", Spanish: "Coral", Catalan: "Coral", Portuguese: "Corália", Romanian: ""}},
	&Name{English, spellings{English: "Corine", German: "", Dutch: "Corina", Latin: "", French: "", Italian: "Corina", Spanish: "", Catalan: "Corina", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Cornelia", German: "", Dutch: "Cornelia", Latin: "", French: "", Italian: "Cornelia", Spanish: "", Catalan: "Cornélia", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Cynthia", German: "", Dutch: "Cynthia", Latin: "", French: "", Italian: "Cinzia", Spanish: "", Catalan: "Cíntia", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Dalia", German: "", Dutch: "Dahlia", Latin: "", French: "", Italian: "Dalia", Spanish: "", Catalan: "Dália", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Delilah", German: "", Dutch: "Delila", Latin: "", French: "", Italian: "", Spanish: "", Catalan: "Dalila", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Daniela", German: "", Dutch: "Daniëlla", Latin: "", French: "", Italian: "Daniela", Spanish: "", Catalan: "Daniela", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Daria", German: "Daria", Dutch: "Daria", Latin: "Daria", French: "", Italian: "Daria", Spanish: "Daría", Catalan: "Daria", Portuguese: "Dária", Romanian: ""}},
	&Name{English, spellings{English: "Deborah", German: "Deborah", Dutch: "Debora", Latin: "Debora", French: "Déborah", Italian: "Debora", Spanish: "Débora", Catalan: "Dèbora", Portuguese: "Débora", Romanian: ""}},
	&Name{English, spellings{English: "Diana", German: "Diana", Dutch: "Diana", Latin: "Diana", French: "Diane", Italian: "Diana", Spanish: "Diana", Catalan: "Diana", Portuguese: "Diana", Romanian: "Diana"}},
	&Name{English, spellings{English: "Dinah", German: "Dina", Dutch: "Dina", Latin: "", French: "Dine", Italian: "Dina", Spanish: "Dina", Catalan: "Dina", Portuguese: "Dina", Romanian: ""}},
	&Name{English, spellings{English: "Denise", German: "", Dutch: "Denise", Latin: "Dionysia", French: "Denise", Italian: "Dionigia", Spanish: "", Catalan: "Dionisia", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Doris", German: "Doris", Dutch: "Doris", Latin: "Doris", French: "Doris", Italian: "Doris", Spanish: "Doris", Catalan: "", Portuguese: "Dóris", Romanian: "Dorina"}},
	&Name{English, spellings{English: "Dominique", German: "", Dutch: "Dominika", Latin: "Dominica", French: "Dominique", Italian: "Domenica", Spanish: "", Catalan: "Domenigas", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Dora", German: "", Dutch: "Dora", Latin: "", French: "", Italian: "Dora", Spanish: "", Catalan: "Dora", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Dorothy", German: "Dorothea", Dutch: "Dorothea", Latin: "Dorothea", French: "Dorothée", Italian: "Dorotea", Spanish: "Dorotea", Catalan: "Dorotea", Portuguese: "Doroteia; Dorotéia", Romanian: "Dorothea"}},
	&Name{English, spellings{English: "Edith", German: "Edith", Dutch: "Edith", Latin: "Edita", French: "Édith", Italian: "", Spanish: "Edita", Catalan: "Edita", Portuguese: "Edite", Romanian: ""}},
	&Name{English, spellings{English: "Edmunda", German: "", Dutch: "Edmonde", Latin: "", French: "Edmonde", Italian: "Edmonda", Spanish: "", Catalan: "", Portuguese: "Edmunda", Romanian: ""}},
	&Name{English, spellings{English: "Edna", German: "", Dutch: "Edna", Latin: "", French: "", Italian: "", Spanish: "", Catalan: "", Portuguese: "Edna", Romanian: ""}},
	&Name{English, spellings{English: "Edwarda", German: "", Dutch: "Eduarda", Latin: "", French: "Edouarde", Italian: "Edoarda", Spanish: "", Catalan: "", Portuguese: "Eduarda", Romanian: ""}},
	&Name{English, spellings{English: "Eleanor", German: "Eleonore", Dutch: "Eleonora", Latin: "Eleanora", French: "Éléonore", Italian: "Eleonora", Spanish: "Eleonor", Catalan: "Eleonor", Portuguese: "Eleanora", Romanian: "Eleonora"}},
	&Name{English, spellings{English: "Electra", German: "", Dutch: "Elektra", Latin: "Electra", French: "", Italian: "Elettra", Spanish: "", Catalan: "", Portuguese: "Electra", Romanian: ""}},
	&Name{English, spellings{English: "Eliana", German: "", Dutch: "", Latin: "Aeliana", French: "", Italian: "Eliana", Spanish: "", Catalan: "", Portuguese: "Eliana", Romanian: ""}},
	&Name{English, spellings{English: "Eliza", German: "Elise", Dutch: "Elisa", Latin: "", French: "Élise", Italian: "Elisa", Spanish: "Elisa", Catalan: "Elisa", Portuguese: "Elisa", Romanian: ""}},
	&Name{English, spellings{English: "Elizabeth", German: "Elisabeth", Dutch: "Elisabeth", Latin: "Elisabetha", French: "Élisabeth", Italian: "Elisabetta", Spanish: "Elisabet", Catalan: "Elisabet", Portuguese: "Elisabete", Romanian: "Elisabeta"}},
	&Name{English, spellings{English: "Elsa", German: "Elsa", Dutch: "Elsa", Latin: "", French: "Else", Italian: "Elsa", Spanish: "Elsa", Catalan: "Elsa", Portuguese: "Elsa", Romanian: ""}},
	&Name{English, spellings{English: "Elvira", German: "Elvira", Dutch: "Elvira", Latin: "", French: "Elvire", Italian: "Elvira", Spanish: "Elvira", Catalan: "Elvira", Portuguese: "Elvira", Romanian: "Elvira"}},
	&Name{English, spellings{English: "Emerantia", German: "", Dutch: "", Latin: "", French: "", Italian: "Emerenziana", Spanish: "", Catalan: "", Portuguese: "Emeranciana", Romanian: ""}},
	&Name{English, spellings{English: "Emiliana", German: "Emiliane", Dutch: "Emiliana", Latin: "Aemiliana", French: "Émilienne", Italian: "Emiliana", Spanish: "Emiliana", Catalan: "", Portuguese: "Emiliana", Romanian: ""}},
	&Name{English, spellings{English: "Emily", German: "Emilia", Dutch: "Emilia", Latin: "Aemilia", French: "Émilie", Italian: "Emilia", Spanish: "Emilia", Catalan: "Emília", Portuguese: "Emília", Romanian: "Emilia"}},
	&Name{English, spellings{English: "Emma", German: "Emma", Dutch: "Emma", Latin: "", French: "Emma", Italian: "Emma", Spanish: "Emma", Catalan: "Emma", Portuguese: "Ema", Romanian: ""}},
	&Name{English, spellings{English: "Emmanuela", German: "Emmanuela", Dutch: "Emmanuëlle", Latin: "Emmanuela", French: "Emmanuelle", Italian: "Emanuela", Spanish: "Manuela", Catalan: "Manela", Portuguese: "Emanuela", Romanian: "Emanuela"}},
	&Name{English, spellings{English: "Erica", German: "Erika", Dutch: "Erika", Latin: "Erica", French: "Érika", Italian: "Erica", Spanish: "Érica", Catalan: "Èrica", Portuguese: "Erica", Romanian: ""}},
	&Name{English, spellings{English: "Hermelinda", German: "", Dutch: "", Latin: "", French: "", Italian: "Ermelinda", Spanish: "", Catalan: "", Portuguese: "Ermelinda", Romanian: ""}},
	&Name{English, spellings{English: "Ernestina", German: "", Dutch: "Ernestine", Latin: "", French: "", Italian: "Ernesta", Spanish: "", Catalan: "", Portuguese: "Ernestina", Romanian: ""}},
	&Name{English, spellings{English: "Esmeralda", German: "", Dutch: "Esmeralda", Latin: "", French: "Eméraude", Italian: "Smeralda", Spanish: "Esmeralda", Catalan: "Maragda", Portuguese: "Esmeralda", Romanian: "Smaranda"}},
	&Name{English, spellings{English: "Hope", German: "", Dutch: "Esperanza", Latin: "Spes", French: "Espérance", Italian: "Speranza", Spanish: "", Catalan: "", Portuguese: "Esperança", Romanian: ""}},
	&Name{English, spellings{English: "Esther", German: "Esther", Dutch: "Esther", Latin: "Esthera", French: "Esther", Italian: "Ester", Spanish: "Ester", Catalan: "Ester", Portuguese: "Ester", Romanian: "Estera"}},
	&Name{English, spellings{English: "Ethel", German: "", Dutch: "Ethel", Latin: "", French: "", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Eudoxia", German: "", Dutch: "Eudoxia", Latin: "Eudoxia", French: "Eudoxie", Italian: "Eudosia", Spanish: "Eudoxia", Catalan: "Eudòxia", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Euphemia", German: "Euphemia", Dutch: "Eufemia", Latin: "Euphemia", French: "Euphémie", Italian: "Eufemia", Spanish: "Eufemia", Catalan: "Eufèmia", Portuguese: "Eufémia", Romanian: ""}},
	&Name{English, spellings{English: "Eugenia", German: "Eugenia", Dutch: "Eugenie", Latin: "Eugenia", French: "Eugénie", Italian: "Eugenia", Spanish: "Eugenia", Catalan: "Eugènia", Portuguese: "Eugénia", Romanian: "Eugenia"}},
	&Name{English, spellings{English: "Eulalie", German: "Eulalie", Dutch: "Eulalia", Latin: "Eulalia", French: "Eulalie", Italian: "Eulalia", Spanish: "Eulalia", Catalan: "Eulàlia", Portuguese: "Eulália", Romanian: ""}},
	&Name{English, spellings{English: "Eunice", German: "", Dutch: "Eunice", Latin: "", French: "", Italian: "Eunice", Spanish: "Eunice", Catalan: "", Portuguese: "Eunice", Romanian: ""}},
	&Name{English, spellings{English: "Eurydice", German: "", Dutch: "Eurydice", Latin: "", French: "", Italian: "Euridice", Spanish: "Eurídice", Catalan: "Euridice", Portuguese: "Eurídice", Romanian: ""}},
	&Name{English, spellings{English: "Evangeline", German: "", Dutch: "Evangeline", Latin: "", French: "", Italian: "Evangelina", Spanish: "Evangelina", Catalan: "Evangelina", Portuguese: "Evangelina", Romanian: ""}},
	&Name{English, spellings{English: "Eve", German: "Eva", Dutch: "Eva", Latin: "Eva", French: "Ève", Italian: "Eva", Spanish: "Eva", Catalan: "Eva", Portuguese: "Eva", Romanian: ""}},
	&Name{English, spellings{English: "Evelyn", German: "Eveline", Dutch: "Eveline", Latin: "", French: "Évelyne", Italian: "Evelina", Spanish: "Evelina", Catalan: "Evelina", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Fabia", German: "", Dutch: "Fabia", Latin: "Fabia", French: "Fabienne", Italian: "Fabia", Spanish: "", Catalan: "", Portuguese: "Fábia", Romanian: ""}},
	&Name{English, spellings{English: "Fabiola", German: "", Dutch: "Fabiola", Latin: "", French: "", Italian: "Fabiola", Spanish: "Fabiola", Catalan: "Fabiola", Portuguese: "Fabíola", Romanian: ""}},
	&Name{English, spellings{English: "Fatima", German: "", Dutch: "Fatima", Latin: "", French: "Fatima", Italian: "Fatima", Spanish: "Fátima", Catalan: "Fàtima", Portuguese: "Fatima", Romanian: ""}},
	&Name{English, spellings{English: "Felicia", German: "", Dutch: "Felicia", Latin: "", French: "", Italian: "Feliciana", Spanish: "Felisa", Catalan: "Felisa", Portuguese: "Felícia", Romanian: ""}},
	&Name{English, spellings{English: "Felicity", German: "Felizitas", Dutch: "Felicitas", Latin: "Felicitas", French: "Félicité", Italian: "Felicita", Spanish: "Felicidad", Catalan: "Felicitat", Portuguese: "Felicidade", Romanian: ""}},
	&Name{English, spellings{English: "Fernanda", German: "Ferdinanda", Dutch: "Ferdinanda", Latin: "", French: "Fernande", Italian: "Fernanda", Spanish: "Fernanda", Catalan: "", Portuguese: "Fernanda", Romanian: ""}},
	&Name{English, spellings{English: "Flavia", German: "", Dutch: "Flavia", Latin: "Flavia", French: "Flavie", Italian: "Flavia", Spanish: "Flavia", Catalan: "Flàvia", Portuguese: "Flávia", Romanian: ""}},
	&Name{English, spellings{English: "Flora", German: "Flora", Dutch: "Flora", Latin: "Flora", French: "Fleur", Italian: "Flora", Spanish: "Flora", Catalan: "Flora", Portuguese: "Flora", Romanian: ""}},
	&Name{English, spellings{English: "Florence", German: "Florentia", Dutch: "Florence", Latin: "Florentia", French: "Florence", Italian: "Fiorenza", Spanish: "Florencia", Catalan: "Florència", Portuguese: "Florência", Romanian: "Florenţa"}},
	&Name{English, spellings{English: "Florentine", German: "Florentine", Dutch: "Florentina", Latin: "Florentine", French: "", Italian: "Fiorentina", Spanish: "Florentina", Catalan: "Florentina", Portuguese: "Florentina", Romanian: ""}},
	&Name{English, spellings{English: "Frances", German: "Franziska", Dutch: "Francisca", Latin: "Francisca", French: "Françoise", Italian: "Francesca", Spanish: "Francisca", Catalan: "Francesca", Portuguese: "Francisca", Romanian: ""}},
	&Name{English, spellings{English: "Fredericka", German: "Friederike", Dutch: "Frederika", Latin: "Frederica", French: "Frédérique", Italian: "Federica", Spanish: "Frederica", Catalan: "Frederica", Portuguese: "Frederica", Romanian: ""}},
	&Name{English, spellings{English: "Fulvia", German: "", Dutch: "Fulvia", Latin: "Fulvia", French: "Fulvie", Italian: "Fulvia", Spanish: "", Catalan: "", Portuguese: "Fúlvia", Romanian: ""}},
	&Name{English, spellings{English: "Gabrielle", German: "Gabriele", Dutch: "Gabriëlle", Latin: "Gabriela", French: "Gabrielle", Italian: "Gabriela", Spanish: "Gabriela", Catalan: "Gabriela", Portuguese: "Gabriela", Romanian: "Gabriela"}},
	&Name{English, spellings{English: "Gemma", German: "Gemma", Dutch: "Gemma", Latin: "Gemma", French: "Gemma", Italian: "Gemma", Spanish: "Gema", Catalan: "Gemma", Portuguese: "Gema", Romanian: ""}},
	&Name{English, spellings{English: "Genoveva", German: "Genovefa", Dutch: "Genovefa", Latin: "", French: "Geneviève", Italian: "Genoveffa", Spanish: "Genoveva", Catalan: "Genoveva", Portuguese: "Genoveva", Romanian: ""}},
	&Name{English, spellings{English: "Georgia", German: "", Dutch: "Georgina", Latin: "", French: "Georgette", Italian: "Giorgia", Spanish: "Georgia", Catalan: "Geòrgia", Portuguese: "Jorgina", Romanian: ""}},
	&Name{English, spellings{English: "Geraldine", German: "Geraldine", Dutch: "Geraldine", Latin: "", French: "Géraldine", Italian: "Gerardina", Spanish: "Gerardina", Catalan: "", Portuguese: "Geraldina", Romanian: ""}},
	&Name{English, spellings{English: "Germaine", German: "", Dutch: "Germaine", Latin: "", French: "Germaine", Italian: "Germana", Spanish: "Germana", Catalan: "Germana", Portuguese: "Germana", Romanian: ""}},
	&Name{English, spellings{English: "Gertrude", German: "Gertrud", Dutch: "Geertruida", Latin: "Gertrudis", French: "Gertrude", Italian: "Geltrude", Spanish: "Gertrudis", Catalan: "Gertrudis", Portuguese: "Gertrudes", Romanian: ""}},
	&Name{English, spellings{English: "Gervasia", German: "", Dutch: "", Latin: "", French: "", Italian: "Gervasia", Spanish: "", Catalan: "", Portuguese: "Gervásia", Romanian: ""}},
	&Name{English, spellings{English: "Gilda", German: "Gilda", Dutch: "Gilda", Latin: "", French: "Gilda", Italian: "Gilda", Spanish: "Gilda", Catalan: "Gilda", Portuguese: "Gilda", Romanian: ""}},
	&Name{English, spellings{English: "Gina", German: "", Dutch: "Gina", Latin: "", French: "", Italian: "Gina", Spanish: "Gina", Catalan: "", Portuguese: "Gina", Romanian: ""}},
	&Name{English, spellings{English: "Giselle", German: "Gisela", Dutch: "Gisela", Latin: "", French: "Giselle", Italian: "Gisella", Spanish: "Gisela", Catalan: "Gisela", Portuguese: "Gisela", Romanian: ""}},
	&Name{English, spellings{English: "Gloria", German: "Gloria", Dutch: "Gloria", Latin: "Gloria", French: "Gloire", Italian: "Gloria", Spanish: "Gloria", Catalan: "Glòria", Portuguese: "Glória", Romanian: ""}},
	&Name{English, spellings{English: "Grace", German: "Grazia", Dutch: "Gratia", Latin: "Gratia", French: "Grâce", Italian: "Grazia", Spanish: "Gracia", Catalan: "Gràcia", Portuguese: "Graça", Romanian: "Graţiela"}},
	&Name{English, spellings{English: "Graciela", German: "", Dutch: "", Latin: "", French: "", Italian: "Graziella", Spanish: "Graciosa", Catalan: "Graciosa", Portuguese: "Gracília", Romanian: ""}},
	&Name{English, spellings{English: "Hedwig", German: "Hedwig", Dutch: "Hedwig", Latin: "Eduvigis", French: "Hedwige", Italian: "Edvige", Spanish: "Eduvigis", Catalan: "Eduvigis", Portuguese: "Edviges", Romanian: ""}},
	&Name{English, spellings{English: "Helen", German: "Helena", Dutch: "Helena", Latin: "Helena", French: "Hélène", Italian: "Elena", Spanish: "Helena", Catalan: "Helena", Portuguese: "Helena", Romanian: "Ileana"}},
	&Name{English, spellings{English: "Helewise", German: "", Dutch: "Heloise", Latin: "", French: "Héloïse", Italian: "Eloisa", Spanish: "Eloísa", Catalan: "Eloísa", Portuguese: "Heloísa", Romanian: ""}},
	&Name{English, spellings{English: "Henrietta", German: "Henriette", Dutch: "Hendrika", Latin: "Henrica", French: "Henriette", Italian: "Enrica", Spanish: "Enriqueta", Catalan: "Enriqueta", Portuguese: "Henriqueta", Romanian: ""}},
	&Name{English, spellings{English: "Herminia", German: "", Dutch: "", Latin: "", French: "", Italian: "Erminia", Spanish: "", Catalan: "", Portuguese: "Hermínia", Romanian: ""}},
	&Name{English, spellings{English: "Hilary", German: "", Dutch: "Hilaria", Latin: "", French: "", Italian: "Ilaria", Spanish: "", Catalan: "", Portuguese: "Hilária", Romanian: ""}},
	&Name{English, spellings{English: "Hilda", German: "Hilde", Dutch: "Hilda", Latin: "", French: "Hilda", Italian: "Ilda", Spanish: "Hilda", Catalan: "Hilda", Portuguese: "Hilda", Romanian: ""}},
	&Name{English, spellings{English: "Hildegard", German: "Hildegard", Dutch: "Hildegard", Latin: "", French: "", Italian: "Ildegarda", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Hortensia", German: "", Dutch: "Hortense", Latin: "Hortensia", French: "Hortense", Italian: "Ortensia", Spanish: "", Catalan: "", Portuguese: "Horténsia", Romanian: ""}},
	&Name{English, spellings{English: "Ida", German: "Ida", Dutch: "Ida", Latin: "", French: "", Italian: "Ida", Spanish: "", Catalan: "", Portuguese: "Ida", Romanian: ""}},
	&Name{English, spellings{English: "Ignatia", German: "", Dutch: "Ignatia", Latin: "", French: "", Italian: "Ignazia", Spanish: "", Catalan: "", Portuguese: "Inácia", Romanian: ""}},
	&Name{English, spellings{English: "Iphigenia", German: "", Dutch: "Ifigenia", Latin: "", French: "Iphigénie", Italian: "Ifigenia", Spanish: "", Catalan: "", Portuguese: "Ifigénia", Romanian: ""}},
	&Name{English, spellings{English: "Ilona", German: "Ilona", Dutch: "Ilona", Latin: "Helena", French: "", Italian: "Ilona", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Ingrid", German: "", Dutch: "Ingrid", Latin: "", French: "", Italian: "Ingrid", Spanish: "", Catalan: "", Portuguese: "Ingrid", Romanian: ""}},
	&Name{English, spellings{English: "Iolanda", German: "", Dutch: "Jolanda", Latin: "", French: "", Italian: "Jolanda", Spanish: "", Catalan: "", Portuguese: "Iolanda", Romanian: ""}},
	&Name{English, spellings{English: "Irene", German: "Irene", Dutch: "Irene", Latin: "Irene", French: "Irène", Italian: "Irene", Spanish: "Irene", Catalan: "Irene", Portuguese: "Irene", Romanian: "Irina"}},
	&Name{English, spellings{English: "Iris", German: "Iris", Dutch: "Iris", Latin: "Iris", French: "Iris", Italian: "Iris", Spanish: "Iris", Catalan: "Iris", Portuguese: "Íris", Romanian: "Iris"}},
	&Name{English, spellings{English: "Irma", German: "Irma", Dutch: "Irma", Latin: "", French: "Irma", Italian: "Irma", Spanish: "Irma", Catalan: "Irma", Portuguese: "Irma", Romanian: ""}},
	&Name{English, spellings{English: "Isabelle", German: "Isabelle", Dutch: "Isabelle", Latin: "", French: "Isabelle", Italian: "Isabella", Spanish: "Isabel", Catalan: "Isabel", Portuguese: "Isabel", Romanian: "Izabela"}},
	&Name{English, spellings{English: "Isaura", German: "", Dutch: "Isaura", Latin: "", French: "", Italian: "Isaura", Spanish: "", Catalan: "", Portuguese: "Isaura", Romanian: ""}},
	&Name{English, spellings{English: "Isadora", German: "", Dutch: "Isidora", Latin: "", French: "", Italian: "", Spanish: "", Catalan: "", Portuguese: "Isidora", Romanian: ""}},
	&Name{English, spellings{English: "Isis", German: "", Dutch: "Isis", Latin: "Isis", French: "Isis", Italian: "Iside", Spanish: "Isis", Catalan: "Isis", Portuguese: "Ísis", Romanian: ""}},
	&Name{English, spellings{English: "Isolda", German: "Isolde", Dutch: "Isolde", Latin: "", French: "Iseult", Italian: "Isotta", Spanish: "Isolda", Catalan: "Isolda", Portuguese: "Isolda", Romanian: ""}},
	&Name{English, spellings{English: "Ivana", German: "", Dutch: "Ivana", Latin: "", French: "", Italian: "Ivana", Spanish: "", Catalan: "", Portuguese: "Ivana", Romanian: ""}},
	&Name{English, spellings{English: "Ivette", German: "Ivette", Dutch: "Ivette", Latin: "", French: "Yvette", Italian: "", Spanish: "Yvette", Catalan: "", Portuguese: "Ivete", Romanian: ""}},
	&Name{English, spellings{English: "Ivonne", German: "Yvonne", Dutch: "Ivonne", Latin: "", French: "Yvonne", Italian: "", Spanish: "Yvette", Catalan: "", Portuguese: "Ivone", Romanian: ""}},
	&Name{English, spellings{English: "Jacinta", German: "", Dutch: "Jacinta", Latin: "", French: "", Italian: "Giacinta", Spanish: "", Catalan: "", Portuguese: "Jacinta", Romanian: ""}},
	&Name{English, spellings{English: "Jacqueline", German: "Jacqueline", Dutch: "Jacqueline", Latin: "Iacoba", French: "Jacqueline", Italian: "Giacomina", Spanish: "Jacoba", Catalan: "", Portuguese: "Jaquelina", Romanian: ""}},
	&Name{English, spellings{English: "Jade", German: "Jade", Dutch: "Jade", Latin: "", French: "Jade", Italian: "Giada", Spanish: "Jade", Catalan: "", Portuguese: "Jade", Romanian: ""}},
	&Name{English, spellings{English: "Jane", German: "Johanna", Dutch: "Johanna", Latin: "Ioanna", French: "Jeanne", Italian: "Giovanna", Spanish: "Juana", Catalan: "Joana", Portuguese: "Joana", Romanian: "Ioana"}},
	&Name{English, spellings{English: "Janet", German: "Jeannette", Dutch: "Jeannette", Latin: "", French: "Jeannette", Italian: "Gianna", Spanish: "Juanita", Catalan: "", Portuguese: "Janete", Romanian: ""}},
	&Name{English, spellings{English: "Jasmine", German: "", Dutch: "Jasmijn", Latin: "", French: "", Italian: "Gelsomina", Spanish: "", Catalan: "", Portuguese: "Jasmin", Romanian: ""}},
	&Name{English, spellings{English: "Jennifer", German: "Jennifer", Dutch: "Jennifer", Latin: "", French: "", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Jessica", German: "Jessica", Dutch: "Jessica", Latin: "", French: "", Italian: "Gessica", Spanish: "Jessica", Catalan: "", Portuguese: "Jessica", Romanian: ""}},
	&Name{English, spellings{English: "Jocasta", German: "", Dutch: "Iocaste", Latin: "", French: "", Italian: "Giocasta", Spanish: "", Catalan: "", Portuguese: "Jocasta", Romanian: ""}},
	&Name{English, spellings{English: "Josepha", German: "", Dutch: "Jozefa", Latin: "", French: "", Italian: "Giuseppa", Spanish: "", Catalan: "", Portuguese: "Josefa", Romanian: ""}},
	&Name{English, spellings{English: "Josephine", German: "Josephine", Dutch: "Josefien", Latin: "Iosephina", French: "Joséphine", Italian: "Giuseppina", Spanish: "Josefina", Catalan: "", Portuguese: "Josefina", Romanian: ""}},
	&Name{English, spellings{English: "Judith", German: "Judith", Dutch: "Judith", Latin: "Iudita", French: "Judith", Italian: "Giuditta", Spanish: "Judit", Catalan: "Judit", Portuguese: "Judite", Romanian: ""}},
	&Name{English, spellings{English: "Julia", German: "Julia", Dutch: "Julia", Latin: "Iulia", French: "Julie", Italian: "Giulia", Spanish: "Julia", Catalan: "Júlia", Portuguese: "Júlia", Romanian: "Iulia"}},
	&Name{English, spellings{English: "Juliet", German: "Julia", Dutch: "Juliëtte", Latin: "Iulia", French: "Juliette", Italian: "Giulietta", Spanish: "Julieta", Catalan: "", Portuguese: "Julieta", Romanian: ""}},
	&Name{English, spellings{English: "Justine", German: "", Dutch: "Justine", Latin: "", French: "", Italian: "Giustina", Spanish: "", Catalan: "", Portuguese: "Justina", Romanian: ""}},
	&Name{English, spellings{English: "Kyra", German: "Kyra", Dutch: "Kyra", Latin: "", French: "", Italian: "", Spanish: "Kira", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Lara", German: "Lara", Dutch: "Lara", Latin: "", French: "Lara", Italian: "Lara", Spanish: "Lara", Catalan: "Lara", Portuguese: "Lara", Romanian: ""}},
	&Name{English, spellings{English: "Larissa", German: "Larissa", Dutch: "Larissa", Latin: "", French: "Larisse", Italian: "Lara", Spanish: "Larisa", Catalan: "Lara", Portuguese: "Larissa", Romanian: "Larisa"}},
	&Name{English, spellings{English: "Laura", German: "Laura", Dutch: "Laura", Latin: "Laura", French: "Laure", Italian: "Laura", Spanish: "Laura", Catalan: "Laura", Portuguese: "Laura", Romanian: "Laura"}},
	&Name{English, spellings{English: "Laurence", German: "Laurentia", Dutch: "Laurentia", Latin: "Laurentia", French: "Laurence", Italian: "Lorenza", Spanish: "Lorenza", Catalan: "Llorença", Portuguese: "Lourença", Romanian: ""}},
	&Name{English, spellings{English: "Lavinia", German: "", Dutch: "Lavinia", Latin: "", French: "", Italian: "Lavinia", Spanish: "", Catalan: "", Portuguese: "Lavínia", Romanian: ""}},
	&Name{English, spellings{English: "Leah", German: "Lea", Dutch: "Lea", Latin: "Lea", French: "Léa", Italian: "Lea", Spanish: "Lea", Catalan: "Lea", Portuguese: "Lea", Romanian: "Lia"}},
	&Name{English, spellings{English: "Leila", German: "Laila", Dutch: "Leila", Latin: "", French: "Leila", Italian: "", Spanish: "Leila", Catalan: "Leila", Portuguese: "Leila", Romanian: ""}},
	&Name{English, spellings{English: "Leonora", German: "Leonore", Dutch: "Leonora", Latin: "Eleonora", French: "Léonore", Italian: "Leonora", Spanish: "Leonor", Catalan: "", Portuguese: "Leonor", Romanian: ""}},
	&Name{English, spellings{English: "Leopolda", German: "", Dutch: "Leopolda", Latin: "", French: "", Italian: "Leopolda", Spanish: "", Catalan: "", Portuguese: "Leopolda", Romanian: ""}},
	&Name{English, spellings{English: "Laetitia", German: "", Dutch: "", Latin: "", French: "", Italian: "Letizia", Spanish: "", Catalan: "", Portuguese: "Letícia", Romanian: ""}},
	&Name{English, spellings{English: "Lillian", German: "Liliane", Dutch: "Lilian", Latin: "Liliana", French: "Lilianne", Italian: "Liliana", Spanish: "Liliana", Catalan: "Liliana", Portuguese: "Liliana", Romanian: "Liliana"}},
	&Name{English, spellings{English: "Lily", German: "Lilian", Dutch: "Lilian", Latin: "Lilia", French: "Lilie", Italian: "Lilia", Spanish: "Lilia", Catalan: "", Portuguese: "Lília", Romanian: "Lili"}},
	&Name{English, spellings{English: "Lina", German: "", Dutch: "Lina", Latin: "", French: "", Italian: "Lina", Spanish: "", Catalan: "", Portuguese: "Lina", Romanian: ""}},
	&Name{English, spellings{English: "Linda", German: "", Dutch: "Linda", Latin: "", French: "", Italian: "Linda", Spanish: "", Catalan: "", Portuguese: "Linda", Romanian: ""}},
	&Name{English, spellings{English: "Lisa", German: "Lisa", Dutch: "Lisa", Latin: "", French: "Lise", Italian: "Lisa", Spanish: "Lisa", Catalan: "", Portuguese: "Lisa", Romanian: ""}},
	&Name{English, spellings{English: "Livia", German: "", Dutch: "Livia", Latin: "", French: "", Italian: "Livia", Spanish: "", Catalan: "", Portuguese: "Lívia", Romanian: ""}},
	&Name{English, spellings{English: "Lora", German: "Lore", Dutch: "", Latin: "Laura", French: "", Italian: "Lora", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Louisa", German: "Luise", Dutch: "Louise", Latin: "Ludovica", French: "Louise", Italian: "Luisa", Spanish: "Luisa", Catalan: "Lluïsa", Portuguese: "Luísa", Romanian: ""}},
	&Name{English, spellings{English: "Lucy", German: "Lucie", Dutch: "Lucia", Latin: "Lucia", French: "Lucie", Italian: "Lucia", Spanish: "Lucía", Catalan: "Llúcia", Portuguese: "Lúcia", Romanian: ""}},
	&Name{English, spellings{English: "Luciana", German: "", Dutch: "Luciana", Latin: "", French: "", Italian: "Luciana", Spanish: "", Catalan: "", Portuguese: "Luciana", Romanian: ""}},
	&Name{English, spellings{English: "Lucille", German: "", Dutch: "Lucille", Latin: "", French: "", Italian: "Lucilla", Spanish: "", Catalan: "", Portuguese: "Lucília", Romanian: ""}},
	&Name{English, spellings{English: "Lucinda", German: "", Dutch: "Lucinda", Latin: "", French: "", Italian: "Lucinda", Spanish: "", Catalan: "", Portuguese: "Lucinda", Romanian: ""}},
	&Name{English, spellings{English: "Lucretia", German: "", Dutch: "Lucretia", Latin: "", French: "", Italian: "Lucrezia", Spanish: "", Catalan: "", Portuguese: "Lucrécia", Romanian: ""}},
	&Name{English, spellings{English: "Ludumila", German: "", Dutch: "Ludmila", Latin: "", French: "", Italian: "Ludmilla", Spanish: "", Catalan: "", Portuguese: "Ludiomila", Romanian: ""}},
	&Name{English, spellings{English: "Lydia", German: "Lydia", Dutch: "Lydia", Latin: "Lydia", French: "Lydie", Italian: "Lidia", Spanish: "Lidia", Catalan: "", Portuguese: "Lídia", Romanian: "Lidia"}},
	&Name{English, spellings{English: "Mabel", German: "Mabel", Dutch: "Mabel", Latin: "", French: "Amabile", Italian: "Amabile", Spanish: "", Catalan: "", Portuguese: "Mabel", Romanian: ""}},
	&Name{English, spellings{English: "Magdalen", German: "Magdalene", Dutch: "Magdalena", Latin: "Magdalena", French: "Madeleine", Italian: "Maddalena", Spanish: "Magdalena", Catalan: "", Portuguese: "Madalena", Romanian: "Mădălina"}},
	&Name{English, spellings{English: "Malvina", German: "Malvine", Dutch: "Malvina", Latin: "", French: "Malvina", Italian: "Malvina", Spanish: "Malvina", Catalan: "", Portuguese: "Malvina", Romanian: ""}},
	&Name{English, spellings{English: "Marcella", German: "", Dutch: "Marcella", Latin: "", French: "", Italian: "Marcella", Spanish: "", Catalan: "", Portuguese: "Marcela", Romanian: ""}},
	&Name{English, spellings{English: "Margaret", German: "Margarethe", Dutch: "Margaretha", Latin: "Margarita", French: "Marguérite", Italian: "Margherita", Spanish: "Margarita", Catalan: "", Portuguese: "Margarida", Romanian: "Margareta"}},
	&Name{English, spellings{English: "Marian", German: "Marianne", Dutch: "Marianne", Latin: "Mariana", French: "Marianne", Italian: "Marianna", Spanish: "Mariana", Catalan: "", Portuguese: "Mariana", Romanian: "Mariana"}},
	&Name{English, spellings{English: "Marina", German: "Marina", Dutch: "Marina", Latin: "Marina", French: "Marine", Italian: "Marina", Spanish: "Marina", Catalan: "", Portuguese: "Marina", Romanian: ""}},
	&Name{English, spellings{English: "Marissa", German: "Marissa", Dutch: "Marissa", Latin: "", French: "Marissa", Italian: "Marisa", Spanish: "Marisa", Catalan: "", Portuguese: "Marisa", Romanian: ""}},
	&Name{English, spellings{English: "Martha", German: "Martha", Dutch: "Martha", Latin: "Martha", French: "Marthe", Italian: "Marta", Spanish: "Marta", Catalan: "", Portuguese: "Marta", Romanian: ""}},
	&Name{English, spellings{English: "Mary", German: "Maria", Dutch: "Maria", Latin: "Maria", French: "Marie", Italian: "Maria", Spanish: "María", Catalan: "", Portuguese: "Maria", Romanian: "Maria"}},
	&Name{English, spellings{English: "Maud", German: "Mathilde", Dutch: "Mathilde", Latin: "", French: "Mathilde", Italian: "Matilda", Spanish: "", Catalan: "", Portuguese: "Matilde", Romanian: ""}},
	&Name{English, spellings{English: "May", German: "Mai", Dutch: "Mai", Latin: "Maia", French: "Mai", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Maya", German: "Maja", Dutch: "Maja", Latin: "Maia", French: "Maya", Italian: "Maia", Spanish: "Maya", Catalan: "Maia", Portuguese: "Maija", Romanian: ""}},
	&Name{English, spellings{English: "Megan", German: "", Dutch: "", Latin: "", French: "Mégane", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Melanie", German: "Melanie", Dutch: "Melanie", Latin: "Melania", French: "Mélanie", Italian: "Melania", Spanish: "", Catalan: "", Portuguese: "Melania", Romanian: "Melania"}},
	&Name{English, spellings{English: "Michelle", German: "Michaela", Dutch: "Michaëla", Latin: "Michaela", French: "Michelle", Italian: "Michela", Spanish: "", Catalan: "", Portuguese: "Micaela", Romanian: "Mihaela"}},
	&Name{English, spellings{English: "Mildred", German: "Mildred", Dutch: "Mildred", Latin: "", French: "", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Muriel", German: "Muriel", Dutch: "Muriel", Latin: "", French: "Murielle", Italian: "", Spanish: "Muriel", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Nadia", German: "Nadja", Dutch: "Nadia", Latin: "", French: "Nadia", Italian: "Nadia", Spanish: "", Catalan: "", Portuguese: "Nádia", Romanian: "Nadia"}},
	&Name{English, spellings{English: "Naomi", German: "Naomi", Dutch: "Naomi", Latin: "Naomi", French: "Noémie", Italian: "Noemi", Spanish: "Noemí", Catalan: "", Portuguese: "Naomi", Romanian: ""}},
	&Name{English, spellings{English: "Narcissa", German: "", Dutch: "Narcissa", Latin: "Narcissa", French: "Narcisse", Italian: "Narcissa", Spanish: "Narcisa", Catalan: "", Portuguese: "Narcisa", Romanian: ""}},
	&Name{English, spellings{English: "Natasha", German: "Natascha", Dutch: "Natasja", Latin: "", French: "Natacha", Italian: "Natascia", Spanish: "", Catalan: "", Portuguese: "Natacha", Romanian: ""}},
	&Name{English, spellings{English: "Natalie", German: "Natalie", Dutch: "Nathalie", Latin: "Natalia", French: "Nathalie", Italian: "Natalia", Spanish: "Natalia", Catalan: "", Portuguese: "Natália", Romanian: "Natalia"}},
	&Name{English, spellings{English: "Nicole", German: "Nicola", Dutch: "Nicole", Latin: "", French: "Nicole", Italian: "Nicoletta", Spanish: "Nicolasa", Catalan: "", Portuguese: "Nicole", Romanian: "Nicoleta"}},
	&Name{English, spellings{English: "Nina", German: "Nina", Dutch: "Nina", Latin: "", French: "Nina", Italian: "Nina", Spanish: "Nina", Catalan: "", Portuguese: "Nina", Romanian: ""}},
	&Name{English, spellings{English: "Nora", German: "", Dutch: "Nora", Latin: "", French: "", Italian: "Nora", Spanish: "", Catalan: "", Portuguese: "Nora", Romanian: ""}},
	&Name{English, spellings{English: "Octavia", German: "", Dutch: "Octavia", Latin: "Octavia", French: "Octavie", Italian: "Ottavia", Spanish: "", Catalan: "", Portuguese: "Octávia", Romanian: ""}},
	&Name{English, spellings{English: "Odilia", German: "", Dutch: "Odilia", Latin: "", French: "Odile", Italian: "Odilia", Spanish: "", Catalan: "", Portuguese: "Odília", Romanian: ""}},
	&Name{English, spellings{English: "Olga", German: "Olga", Dutch: "Olga", Latin: "", French: "Olga", Italian: "Olga", Spanish: "Olga", Catalan: "", Portuguese: "Olga", Romanian: "Olga"}},
	&Name{English, spellings{English: "Olympia", German: "Olympia", Dutch: "Olympia", Latin: "Olympia", French: "Olympe", Italian: "Olimpia", Spanish: "Olimpia", Catalan: "", Portuguese: "Olímpia", Romanian: "Olimpia"}},
	&Name{English, spellings{English: "Olivia", German: "Olivia", Dutch: "Olivia", Latin: "Olivia", French: "Olivia", Italian: "Olivia", Spanish: "Olivia", Catalan: "Olivia", Portuguese: "Olívia", Romanian: "Olivia"}},
	&Name{English, spellings{English: "Ophelia", German: "Ophelia", Dutch: "Ofelia", Latin: "Ophelia", French: "Ophélie", Italian: "Ofelia", Spanish: "Ofelia", Catalan: "", Portuguese: "Ofélia", Romanian: ""}},
	&Name{English, spellings{English: "Pandora", German: "", Dutch: "Pandora", Latin: "", French: "", Italian: "Pandora", Spanish: "", Catalan: "", Portuguese: "Pandora", Romanian: ""}},
	&Name{English, spellings{English: "Patricia", German: "Patrizia", Dutch: "Patricia", Latin: "Patricia", French: "Patricia", Italian: "Patrizia", Spanish: "Patricia", Catalan: "", Portuguese: "Patrícia", Romanian: "Patricia"}},
	&Name{English, spellings{English: "Paula", German: "Paula", Dutch: "Paula", Latin: "Paula", French: "Paule", Italian: "Paola", Spanish: "Paula", Catalan: "", Portuguese: "Paula", Romanian: "Paula"}},
	&Name{English, spellings{English: "Pauline", German: "Pauline", Dutch: "Pauline", Latin: "Paulina", French: "Pauline", Italian: "Paolina", Spanish: "", Catalan: "", Portuguese: "Paulina", Romanian: "Paulina"}},
	&Name{English, spellings{English: "Pelagia", German: "", Dutch: "Pelagia", Latin: "Pelagia", French: "Pélagie", Italian: "Pelagia", Spanish: "", Catalan: "", Portuguese: "Pelagia", Romanian: ""}},
	&Name{English, spellings{English: "Penelope", German: "Penelope", Dutch: "Penelope", Latin: "Penelope", French: "Pénélope", Italian: "Penelope", Spanish: "Penélope", Catalan: "", Portuguese: "", Romanian: "Penélope"}},
	&Name{English, spellings{English: "Petra", German: "", Dutch: "Petra", Latin: "", French: "", Italian: "Piera", Spanish: "", Catalan: "", Portuguese: "Petra", Romanian: ""}},
	&Name{English, spellings{English: "Petronilla", German: "", Dutch: "Petronella", Latin: "", French: "", Italian: "Petronilla", Spanish: "", Catalan: "", Portuguese: "Petronilha", Romanian: ""}},
	&Name{English, spellings{English: "Philippa", German: "Philippa", Dutch: "Philippine", Latin: "Philippina", French: "Philippine", Italian: "Filippa", Spanish: "Felipa", Catalan: "Felipa", Portuguese: "Filipa", Romanian: ""}},
	&Name{English, spellings{English: "Philomena", German: "Philomene", Dutch: "", Latin: "Philomena", French: "Philomène", Italian: "Filomena", Spanish: "Filomena", Catalan: "Filomena", Portuguese: "Filomena", Romanian: ""}},
	&Name{English, spellings{English: "Phoebe", German: "", Dutch: "Phoebe", Latin: "Phoebe", French: "", Italian: "Febe", Spanish: "Febe", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Pia", German: "Pia", Dutch: "Pia", Latin: "Pia", French: "Pia", Italian: "Pia", Spanish: "Pia", Catalan: "", Portuguese: "Pia", Romanian: ""}},
	&Name{English, spellings{English: "Pietas", German: "", Dutch: "Pietas", Latin: "Pietas", French: "Pieté", Italian: "Pietà", Spanish: "Piedad", Catalan: "Pietat", Portuguese: "Piedade", Romanian: ""}},
	&Name{English, spellings{English: "Priscilla", German: "", Dutch: "Priscilla", Latin: "", French: "", Italian: "Priscilla", Spanish: "", Catalan: "", Portuguese: "Priscila", Romanian: ""}},
	&Name{English, spellings{English: "Rachel", German: "Rachel", Dutch: "Rachel", Latin: "Rachel", French: "Rachel", Italian: "Rachele", Spanish: "Raquel", Catalan: "", Portuguese: "Raquel", Romanian: ""}},
	&Name{English, spellings{English: "Raphaela", German: "", Dutch: "Rafaëlla", Latin: "", French: "", Italian: "Raffaela", Spanish: "", Catalan: "", Portuguese: "Rafaela", Romanian: ""}},
	&Name{English, spellings{English: "Raymonda", German: "", Dutch: "Raymonda", Latin: "", French: "", Italian: "Raimonda", Spanish: "", Catalan: "", Portuguese: "Raimunda", Romanian: ""}},
	&Name{English, spellings{English: "Rebecca", German: "Rebekka", Dutch: "Rebekka", Latin: "Rebecca", French: "Rebecca", Italian: "Rebecca", Spanish: "Rebeca", Catalan: "", Portuguese: "Rebeca", Romanian: ""}},
	&Name{English, spellings{English: "Regina", German: "Regina", Dutch: "Regina", Latin: "Regina", French: "Régina", Italian: "Regina", Spanish: "Regina", Catalan: "", Portuguese: "Regina", Romanian: "Reghina"}},
	&Name{English, spellings{English: "Renata", German: "Renate", Dutch: "Renate", Latin: "Renata", French: "Renée", Italian: "Renata", Spanish: "Renata", Catalan: "", Portuguese: "Renata", Romanian: ""}},
	&Name{English, spellings{English: "Richarda", German: "", Dutch: "Richarda", Latin: "", French: "", Italian: "Riccarda", Spanish: "", Catalan: "", Portuguese: "Ricarda", Romanian: ""}},
	&Name{English, spellings{English: "Rita", German: "", Dutch: "Rita", Latin: "", French: "", Italian: "Rita", Spanish: "", Catalan: "", Portuguese: "Rita", Romanian: ""}},
	&Name{English, spellings{English: "Rose", German: "Rose", Dutch: "Rosa", Latin: "Rosa", French: "Rose", Italian: "Rosa", Spanish: "Rosa", Catalan: "", Portuguese: "Rosa", Romanian: ""}},
	&Name{English, spellings{English: "Rosaline", German: "Rosalie", Dutch: "Rosalie", Latin: "Rosalia", French: "Rosalie", Italian: "Rosalia", Spanish: "Rosalía", Catalan: "", Portuguese: "Rosalina", Romanian: ""}},
	&Name{English, spellings{English: "Rosemary", German: "Rosemarie", Dutch: "Rosemarie", Latin: "Rosamaria", French: "Rosemarie", Italian: "Rosamaria", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Roxanne", German: "Roxana", Dutch: "Roxanne", Latin: "Roxana", French: "Roxanne", Italian: "Rossana", Spanish: "Rossana", Catalan: "", Portuguese: "Rosana", Romanian: "Roxana"}},
	&Name{English, spellings{English: "Rufina", German: "", Dutch: "", Latin: "Rufina", French: "", Italian: "Rufina", Spanish: "Rufina", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Ruby", German: "", Dutch: "Ruby", Latin: "", French: "", Italian: "Rubina", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Ruth", German: "Ruth", Dutch: "Ruth", Latin: "Ruth", French: "Rut", Italian: "Ruth", Spanish: "Rute", Catalan: "", Portuguese: "Rute", Romanian: ""}},
	&Name{English, spellings{English: "Sabine", German: "Sabine", Dutch: "Sabina", Latin: "Sabina", French: "Sabine", Italian: "Sabina", Spanish: "Sabina", Catalan: "", Portuguese: "Sabina", Romanian: "Sabina"}},
	&Name{English, spellings{English: "Salomea", German: "", Dutch: "Salome", Latin: "", French: "Salomé", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: "Salomé"}},
	&Name{English, spellings{English: "Samantha", German: "Samantha", Dutch: "Samantha", Latin: "", French: "Samantha", Italian: "Samanta", Spanish: "Samanta", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Sarah", German: "Sarah", Dutch: "Sara", Latin: "Sara", French: "Sara", Italian: "Sara", Spanish: "Sara", Catalan: "Sara", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Seraphina", German: "Seraphina", Dutch: "Serafien", Latin: "Seraphina", French: "Séraphine", Italian: "Serafina", Spanish: "Serafina", Catalan: "Serafina", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Sheila", German: "", Dutch: "Sheila", Latin: "", French: "Sheila", Italian: "", Spanish: "", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Sibyl", German: "Sibille", Dutch: "Sibylla", Latin: "Sibylla", French: "Sibylle", Italian: "Sibilla", Spanish: "Sibila", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Sylvia", German: "Silvia", Dutch: "Silvia", Latin: "Silvia", French: "Sylvie", Italian: "Silvia", Spanish: "Silvia", Catalan: "Sílvia", Portuguese: "Sílvia", Romanian: "Silvia"}},
	&Name{English, spellings{English: "Sonya", German: "", Dutch: "Sonja", Latin: "", French: "Sonia", Italian: "Sonia", Spanish: "", Catalan: "", Portuguese: "", Romanian: "Sónia"}},
	&Name{English, spellings{English: "Sophie", German: "Sophia", Dutch: "Sofia", Latin: "Sophia", French: "Sophie", Italian: "Sofia", Spanish: "Sofía", Catalan: "Sofia", Portuguese: "Sofia", Romanian: "Sofia"}},
	&Name{English, spellings{English: "Stella", German: "Stella", Dutch: "Stella", Latin: "Stella", French: "Stella", Italian: "Stella", Spanish: "Estrella", Catalan: "Estrela", Portuguese: "Estela", Romanian: ""}},
	&Name{English, spellings{English: "Stephanie", German: "Stefanie", Dutch: "Stefanie", Latin: "Stephania", French: "Stéphanie", Italian: "Stefania", Spanish: "Estefanía", Catalan: "", Portuguese: "Estefânia", Romanian: "Ştefana"}},
	&Name{English, spellings{English: "Susan", German: "Susanne", Dutch: "Susanne", Latin: "Susanna", French: "Suzanne", Italian: "Susanna", Spanish: "Susana", Catalan: "Susana", Portuguese: "Susanna", Romanian: "Suzana"}},
	&Name{English, spellings{English: "Tamara", German: "Tamara", Dutch: "Tamara", Latin: "", French: "Tamara", Italian: "Tamara", Spanish: "Tamara", Catalan: "", Portuguese: "Tamara", Romanian: "Tamara"}},
	&Name{English, spellings{English: "Tatyana", German: "Tatjana", Dutch: "Tatjana", Latin: "Tatiana", French: "Tatiana", Italian: "Tatiana", Spanish: "Tatiana", Catalan: "Tanja", Portuguese: "Tatiana", Romanian: ""}},
	&Name{English, spellings{English: "Thecla", German: "Thekla", Dutch: "Thekla", Latin: "Thecla", French: "Thècle", Italian: "Tecla", Spanish: "", Catalan: "", Portuguese: "Tekla", Romanian: ""}},
	&Name{English, spellings{English: "Theodora", German: "Theodora", Dutch: "Theodora", Latin: "Theodora", French: "Théodora", Italian: "Teodora", Spanish: "Teodora", Catalan: "Teodora", Portuguese: "", Romanian: "Teodora"}},
	&Name{English, spellings{English: "Theresia", German: "Therese", Dutch: "Theresia", Latin: "Theresia", French: "Thérèse", Italian: "Teresa", Spanish: "Teresa", Catalan: "Teresa", Portuguese: "Teresa", Romanian: ""}},
	&Name{English, spellings{English: "Tina", German: "Tina", Dutch: "Tina", Latin: "", French: "Tine", Italian: "Tina", Spanish: "Tina", Catalan: "", Portuguese: "Tina", Romanian: ""}},
	&Name{English, spellings{English: "Ulrica", German: "Ulrike", Dutch: "Ulrika", Latin: "Ulrica", French: "", Italian: "Ulrica", Spanish: "Ulrica", Catalan: "", Portuguese: "Ulrica", Romanian: "Ulrica"}},
	&Name{English, spellings{English: "Ursula", German: "Ursula", Dutch: "Ursula", Latin: "Ursula", French: "Ursule", Italian: "Orsola", Spanish: "Ursula", Catalan: "", Portuguese: "Úrsula", Romanian: "Ursula"}},
	&Name{English, spellings{English: "Valentina", German: "Valentina", Dutch: "Valentina", Latin: "Valentina", French: "Valentine", Italian: "Valentina", Spanish: "Valentina", Catalan: "", Portuguese: "Valentina", Romanian: "Valentina"}},
	&Name{English, spellings{English: "Valerie", German: "Valerie", Dutch: "Valerie", Latin: "Valeria", French: "Valérie", Italian: "Valeria", Spanish: "Valeria", Catalan: "", Portuguese: "Valéria", Romanian: "Valeria"}},
	&Name{English, spellings{English: "Vanessa", German: "Vanessa", Dutch: "Vanessa", Latin: "", French: "Vanessa", Italian: "Vanessa", Spanish: "Vanessa", Catalan: "Vanessa", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Venus", German: "", Dutch: "Venus", Latin: "", French: "", Italian: "Venere", Spanish: "", Catalan: "", Portuguese: "Vénus", Romanian: ""}},
	&Name{English, spellings{English: "Vera", German: "Vera", Dutch: "Vera", Latin: "Vera", French: "Véra", Italian: "Vera", Spanish: "", Catalan: "", Portuguese: "Vera", Romanian: ""}},
	&Name{English, spellings{English: "Veronica", German: "Veronika", Dutch: "Veronica", Latin: "Veronica", French: "Véronique", Italian: "Veronica", Spanish: "Verónica", Catalan: "", Portuguese: "Verónica", Romanian: "Veronica"}},
	&Name{English, spellings{English: "Victoria", German: "Viktoria", Dutch: "Victoria", Latin: "Victoria", French: "Victoria", Italian: "Vittoria", Spanish: "Victoria", Catalan: "", Portuguese: "Vitória", Romanian: "Victoria"}},
	&Name{English, spellings{English: "Virginia", German: "Virginie", Dutch: "Virginia", Latin: "Virginia", French: "Virginie", Italian: "Virginia", Spanish: "Virginia", Catalan: "", Portuguese: "Virgínia", Romanian: "Virginia"}},
	&Name{English, spellings{English: "Vivian", German: "Vivien", Dutch: "Viviane", Latin: "Viviana", French: "Vivienne", Italian: "Viviana", Spanish: "", Catalan: "", Portuguese: "Viviana", Romanian: ""}},
	&Name{English, spellings{English: "Wanda", German: "Wanda", Dutch: "Wanda", Latin: "", French: "Vanda", Italian: "Wanda", Spanish: "", Catalan: "", Portuguese: "Vanda", Romanian: ""}},
	&Name{English, spellings{English: "Wilhelmina", German: "Wilhelmine", Dutch: "Wilhelmina", Latin: "Guglielma", French: "Guillemette", Italian: "Guglielmina", Spanish: "Guillerma", Catalan: "Guilleuma", Portuguese: "Guilhermina", Romanian: ""}},
	&Name{English, spellings{English: "Wilma", German: "Wilma", Dutch: "Wilma", Latin: "", French: "Wilma", Italian: "Wilma", Spanish: "Vilma", Catalan: "", Portuguese: "Vilma", Romanian: ""}},
	&Name{English, spellings{English: "Xaveria", German: "Xaveria", Dutch: "Xaviera", Latin: "", French: "Xaviera", Italian: "Saveria", Spanish: "Javiera", Catalan: "", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Xenia", German: "Xenia", Dutch: "Xenia", Latin: "Xenia", French: "", Italian: "Xenia", Spanish: "Xenia", Catalan: "Xènia", Portuguese: "", Romanian: ""}},
	&Name{English, spellings{English: "Zoë", German: "Zoe", Dutch: "Zoë", Latin: "Zoe", French: "Zoé", Italian: "Zoe", Spanish: "", Catalan: "", Portuguese: "Zoe", Romanian: "Zoe"}},
}

// LastNmaes is a collection of last names, with a best-effort approach to supporting
// a given name in multiple languages/cultures at one time. This part is in serious need
// of contributor assistance! Please help fill this out if you can! I made an effort
// to try and fill in a bunch of Romanian ones, to honor the namesake of the library,
// but this needs a lot of TLC!
var LastNames = []*Name{
	&Name{Spanish, spellings{English: "Garcia", Spanish: "Garcia"}},
	&Name{Spanish, spellings{English: "Martinez", Spanish: "Martinez"}},
	&Name{English, spellings{English: "Williams"}},
	&Name{English, spellings{English: "Johnson"}},
	&Name{Spanish, spellings{English: "Rodriguez", Spanish: "Rodriguez"}},
	&Name{English, spellings{English: "Jones"}},
	&Name{Spanish, spellings{English: "Hernandez", Spanish: "Hernandez"}},
	&Name{English, spellings{English: "Brown"}},
	&Name{English, spellings{English: "Davis"}},
	&Name{Spanish, spellings{English: "Garza", Spanish: "Garza"}},
	&Name{Spanish, spellings{English: "Lopez", Spanish: "Lopez"}},
	&Name{Spanish, spellings{English: "Gonzalez", Spanish: "Gonzalez"}},
	&Name{Spanish, spellings{English: "Perez", Spanish: "Perez"}},
	&Name{Spanish, spellings{English: "Flores", Spanish: "Flores"}},
	&Name{Spanish, spellings{English: "Gonzales", Spanish: "Gonzales"}},
	&Name{Spanish, spellings{English: "Ramirez", Spanish: "Ramirez"}},
	&Name{English, spellings{English: "Jackson"}},
	&Name{English, spellings{English: "Moore"}},
	&Name{English, spellings{English: "Wilson"}},
	&Name{Spanish, spellings{English: "Sanchez", Spanish: "Sanchez"}},
	&Name{English, spellings{English: "Taylor"}},
	&Name{English, spellings{English: "Miller"}},
	&Name{English, spellings{English: "Thomas"}},
	&Name{English, spellings{English: "White"}},
	&Name{English, spellings{English: "Thompson"}},
	&Name{English, spellings{English: "Harris"}},
	&Name{English, spellings{English: "Martin"}},
	&Name{English, spellings{English: "Walker"}},
	&Name{English, spellings{English: "Anderson"}},
	&Name{English, spellings{English: "Lewis"}},
	&Name{English, spellings{English: "Allen"}},
	&Name{Spanish, spellings{English: "Torres", Spanish: "Torres"}},
	&Name{English, spellings{English: "Green"}},
	&Name{English, spellings{English: "Clark"}},
	&Name{Spanish, spellings{English: "Gomez", Spanish: "Gomez"}},
	&Name{English, spellings{English: "Hill"}},
	&Name{English, spellings{English: "King"}},
	&Name{English, spellings{English: "Wright"}},
	&Name{English, spellings{English: "Hall"}},
	&Name{English, spellings{English: "Young"}},
	&Name{Spanish, spellings{English: "Castillo", Spanish: "Castillo"}},
	&Name{English, spellings{English: "Lee"}},
	&Name{English, spellings{English: "Adams"}},
	&Name{English, spellings{English: "Trevino"}},
	&Name{English, spellings{English: "Scott"}},
	&Name{Spanish, spellings{English: "Gutierrez", Spanish: "Gutierrez"}},
	&Name{English, spellings{English: "Robinson"}},
	&Name{Spanish, spellings{English: "Reyes", Spanish: "Reyes"}},
	&Name{Spanish, spellings{English: "Vasquez", Spanish: "Vasquez"}},
	&Name{Romanian, spellings{English: "Rusu", Romanian: "Rusu"}},
	&Name{Romanian, spellings{English: "Moldovan", Romanian: "Moldovan"}},
	&Name{Romanian, spellings{Romanian: "Adamache"}},
	&Name{Romanian, spellings{Romanian: "Agarici"}},
	&Name{Romanian, spellings{Romanian: "Albu"}},
	&Name{Romanian, spellings{Romanian: "Alecsandri"}},
	&Name{Romanian, spellings{Romanian: "Alexe"}},
	&Name{Romanian, spellings{Romanian: "Andronic"}},
	&Name{Romanian, spellings{Romanian: "Anghel"}},
	&Name{Romanian, spellings{Romanian: "Anton"}},
	&Name{Romanian, spellings{Romanian: "Antonescu"}},
	&Name{Romanian, spellings{Romanian: "Apostu"}},
	&Name{Romanian, spellings{Romanian: "Ardelean"}},
	&Name{Romanian, spellings{Romanian: "Ardeleanu"}},
	&Name{Romanian, spellings{Romanian: "Argetoianu"}},
	&Name{Romanian, spellings{Romanian: "Arion"}},
	&Name{Romanian, spellings{Romanian: "Atanasiu"}},
	&Name{Romanian, spellings{Romanian: "Athanasiu"}},
	&Name{Romanian, spellings{Romanian: "Avram"}},
	&Name{Romanian, spellings{Romanian: "Avramescu"}},
	&Name{Romanian, spellings{Romanian: "Babeș"}},
	&Name{Romanian, spellings{Romanian: "Bădescu"}},
	&Name{Romanian, spellings{Romanian: "Baicu"}},
	&Name{Romanian, spellings{Romanian: "Bălan"}},
	&Name{Romanian, spellings{Romanian: "Balan"}},
	&Name{Romanian, spellings{Romanian: "Balauru"}},
	&Name{Romanian, spellings{Romanian: "Bănică"}},
	&Name{Romanian, spellings{Romanian: "Bărbulescu"}},
	&Name{Romanian, spellings{Romanian: "Bârlădeanu"}},
	&Name{Romanian, spellings{Romanian: "Bărnuțiu"}},
	&Name{Romanian, spellings{Romanian: "Beldiceanu"}},
	&Name{Romanian, spellings{Romanian: "Bengescu"}},
	&Name{Romanian, spellings{Romanian: "Boboc"}},
	&Name{Romanian, spellings{Romanian: "Bodiu"}},
	&Name{Romanian, spellings{Romanian: "Bogdan"}},
	&Name{Romanian, spellings{Romanian: "Bogza"}},
	&Name{Romanian, spellings{Romanian: "Botez"}},
	&Name{Romanian, spellings{Romanian: "Botezatu"}},
	&Name{Romanian, spellings{Romanian: "Boureanu"}},
	&Name{Romanian, spellings{Romanian: "Brăescu"}},
	&Name{Romanian, spellings{Romanian: "Brâncoveanu"}},
	&Name{Romanian, spellings{Romanian: "Brașoveanu"}},
	&Name{Romanian, spellings{Romanian: "Bratu"}},
	&Name{Romanian, spellings{Romanian: "Breban"}},
	&Name{Romanian, spellings{Romanian: "Brediceanu"}},
	&Name{Romanian, spellings{Romanian: "Bucșă"}},
	&Name{Romanian, spellings{Romanian: "Bucur"}},
	&Name{Romanian, spellings{Romanian: "Bunea"}},
	&Name{Romanian, spellings{Romanian: "Buș"}},
	&Name{Romanian, spellings{Romanian: "Călinescu"}},
	&Name{Romanian, spellings{Romanian: "Călugăreanu"}},
	&Name{Romanian, spellings{Romanian: "Călugăru"}},
	&Name{Romanian, spellings{Romanian: "Cândea"}},
	&Name{Romanian, spellings{Romanian: "Caragiale"}},
	&Name{Romanian, spellings{Romanian: "Catargiu"}},
	&Name{Romanian, spellings{Romanian: "Cazacu"}},
	&Name{Romanian, spellings{Romanian: "Ceaușescu"}},
	&Name{Romanian, spellings{Romanian: "Ceaușu"}},
	&Name{Romanian, spellings{Romanian: "Cebanu"}},
	&Name{Romanian, spellings{Romanian: "Celibidache"}},
	&Name{Romanian, spellings{Romanian: "Cernat"}},
	&Name{Romanian, spellings{Romanian: "Cernea"}},
	&Name{Romanian, spellings{Romanian: "Checicheș"}},
	&Name{Romanian, spellings{Romanian: "Chirilă"}},
	&Name{Romanian, spellings{Romanian: "Chițu"}},
	&Name{Romanian, spellings{Romanian: "Cioabă"}},
	&Name{Romanian, spellings{Romanian: "Cioban"}},
	&Name{Romanian, spellings{Romanian: "Ciobanu"}},
	&Name{Romanian, spellings{Romanian: "Ciocan"}},
	&Name{Romanian, spellings{Romanian: "Ciocanu"}},
	&Name{Romanian, spellings{Romanian: "Ciorbă"}},
	&Name{Romanian, spellings{Romanian: "Ciubotaru"}},
	&Name{Romanian, spellings{Romanian: "Ciucă"}},
	&Name{Romanian, spellings{Romanian: "Coandă"}},
	&Name{Romanian, spellings{Romanian: "Cobălcescu"}},
	&Name{Romanian, spellings{Romanian: "Cocea"}},
	&Name{Romanian, spellings{Romanian: "Codreanu"}},
	&Name{Romanian, spellings{Romanian: "Cojoc"}},
	&Name{Romanian, spellings{Romanian: "Cojocar"}},
	&Name{Romanian, spellings{Romanian: "Cojocaru"}},
	&Name{Romanian, spellings{Romanian: "Comănescu"}},
	&Name{Romanian, spellings{Romanian: "Constantin"}},
	&Name{Romanian, spellings{Romanian: "Constantinescu"}},
	&Name{Romanian, spellings{Romanian: "Corbeanu"}},
	&Name{Romanian, spellings{Romanian: "Corbu"}},
	&Name{Romanian, spellings{Romanian: "Cornea"}},
	&Name{Romanian, spellings{Romanian: "Corneanu"}},
	&Name{Romanian, spellings{Romanian: "Coșovei"}},
	&Name{Romanian, spellings{Romanian: "Costea"}},
	&Name{Romanian, spellings{Romanian: "Costin"}},
	&Name{Romanian, spellings{Romanian: "Costiniu"}},
	&Name{Romanian, spellings{Romanian: "Covaci"}},
	&Name{Romanian, spellings{Romanian: "Cozma"}},
	&Name{Romanian, spellings{Romanian: "Crăciun"}},
	&Name{Romanian, spellings{Romanian: "Creangă"}},
	&Name{Romanian, spellings{Romanian: "Crețu"}},
	&Name{Romanian, spellings{Romanian: "Crișan"}},
	&Name{Romanian, spellings{Romanian: "Cristea"}},
	&Name{Romanian, spellings{Romanian: "Cristescu"}},
	&Name{Romanian, spellings{Romanian: "Croitoru"}},
	&Name{Romanian, spellings{Romanian: "Culianu"}},
	&Name{Romanian, spellings{Romanian: "Cuțov"}},
	&Name{Romanian, spellings{Romanian: "Dabija"}},
	&Name{Romanian, spellings{Romanian: "Damaschin"}},
	&Name{Romanian, spellings{Romanian: "Damian"}},
	&Name{Romanian, spellings{Romanian: "Davidoglu"}},
	&Name{Romanian, spellings{Romanian: "Deleanu"}},
	&Name{Romanian, spellings{Romanian: "Demetrescu"}},
	&Name{Romanian, spellings{Romanian: "Densusianu"}},
	&Name{Romanian, spellings{Romanian: "Diaconescu"}},
	&Name{Romanian, spellings{Romanian: "Diaconu"}},
	&Name{Romanian, spellings{Romanian: "Dimitrescu"}},
	&Name{Romanian, spellings{Romanian: "Dinicu"}},
	&Name{Romanian, spellings{Romanian: "Dinu"}},
	&Name{Romanian, spellings{Romanian: "Dobre"}},
	&Name{Romanian, spellings{Romanian: "Dobrescu"}},
	&Name{Romanian, spellings{Romanian: "Dobrogeanu"}},
	&Name{Romanian, spellings{Romanian: "Donceanu"}},
	&Name{Romanian, spellings{Romanian: "Drăgan"}},
	&Name{Romanian, spellings{Romanian: "Drăganu"}},
	&Name{Romanian, spellings{Romanian: "Drăghicescu"}},
	&Name{Romanian, spellings{Romanian: "Drăghici"}},
	&Name{Romanian, spellings{Romanian: "Dragnea"}},
	&Name{Romanian, spellings{Romanian: "Drăgoi"}},
	&Name{Romanian, spellings{Romanian: "Dulgheru"}},
	&Name{Romanian, spellings{Romanian: "Dumitrescu"}},
	&Name{Romanian, spellings{Romanian: "Dumitru"}},
	&Name{Romanian, spellings{Romanian: "Eliade"}},
	&Name{Romanian, spellings{Romanian: "Enache"}},
	&Name{Romanian, spellings{Romanian: "Enescu"}},
	&Name{Romanian, spellings{Romanian: "Epureanu"}},
	&Name{Romanian, spellings{Romanian: "Fieraru"}},
	&Name{Romanian, spellings{Romanian: "Filotti"}},
	&Name{Romanian, spellings{Romanian: "Florea"}},
	&Name{Romanian, spellings{Romanian: "Florescu"}},
	&Name{Romanian, spellings{Romanian: "Gane"}},
	&Name{Romanian, spellings{Romanian: "Ganea"}},
	&Name{Romanian, spellings{Romanian: "Georgesco"}},
	&Name{Romanian, spellings{Romanian: "Georgescu"}},
	&Name{Romanian, spellings{Romanian: "Gheorghe"}},
	&Name{Romanian, spellings{Romanian: "Gheorghiu"}},
	&Name{Romanian, spellings{Romanian: "Gherea"}},
	&Name{Romanian, spellings{Romanian: "Gherghel"}},
	&Name{Romanian, spellings{Romanian: "Ghimpu"}},
	&Name{Romanian, spellings{Romanian: "Ghiță"}},
	&Name{Romanian, spellings{Romanian: "Giurescu"}},
	&Name{Romanian, spellings{Romanian: "Giurgiu"}},
	&Name{Romanian, spellings{Romanian: "Giurgiuca"}},
	&Name{Romanian, spellings{Romanian: "Giușcă"}},
	&Name{Romanian, spellings{Romanian: "Goga"}},
	&Name{Romanian, spellings{Romanian: "Goian"}},
	&Name{Romanian, spellings{Romanian: "Goldiș"}},
	&Name{Romanian, spellings{Romanian: "Golea"}},
	&Name{Romanian, spellings{Romanian: "Grecu"}},
	&Name{Romanian, spellings{Romanian: "Grigorescu"}},
	&Name{Romanian, spellings{Romanian: "Grosu"}},
	&Name{Romanian, spellings{Romanian: "Groza"}},
	&Name{Romanian, spellings{Romanian: "Hagi"}},
	&Name{Romanian, spellings{Romanian: "Hanganu"}},
	&Name{Romanian, spellings{Romanian: "Haralamb"}},
	&Name{Romanian, spellings{Romanian: "Hasdeu"}},
	&Name{Romanian, spellings{Romanian: "Hațieganu"}},
	&Name{Romanian, spellings{Romanian: "Herea"}},
	&Name{Romanian, spellings{Romanian: "Hoban"}},
	&Name{Romanian, spellings{Romanian: "Hodoș"}},
	&Name{Romanian, spellings{Romanian: "Hossu"}},
	&Name{Romanian, spellings{Romanian: "Huidu"}},
	&Name{Romanian, spellings{Romanian: "Hutopilă"}},
	&Name{Romanian, spellings{Romanian: "Iacob"}},
	&Name{Romanian, spellings{Romanian: "Iacobescu"}},
	&Name{Romanian, spellings{Romanian: "Ilie"}},
	&Name{Romanian, spellings{Romanian: "Ioanid"}},
	&Name{Romanian, spellings{Romanian: "Ionescu"}},
	&Name{Romanian, spellings{Romanian: "Ioniță"}},
	&Name{Romanian, spellings{Romanian: "Iordache"}},
	&Name{Romanian, spellings{Romanian: "Iordan"}},
	&Name{Romanian, spellings{Romanian: "Isopescu"}},
	&Name{Romanian, spellings{Romanian: "Istrati"}},
	&Name{Romanian, spellings{Romanian: "Itu"}},
	&Name{Romanian, spellings{Romanian: "Izbașa"}},
	&Name{Romanian, spellings{Romanian: "Kirițescu"}},
	&Name{Romanian, spellings{Romanian: "Kogălniceanu"}},
	&Name{Romanian, spellings{Romanian: "Lăcustă"}},
	&Name{Romanian, spellings{Romanian: "Lahovary"}},
	&Name{Romanian, spellings{Romanian: "Lascăr"}},
	&Name{Romanian, spellings{Romanian: "Lăzărescu"}},
	&Name{Romanian, spellings{Romanian: "Lecca"}},
	&Name{Romanian, spellings{Romanian: "Luca"}},
	&Name{Romanian, spellings{Romanian: "Lucescu"}},
	&Name{Romanian, spellings{Romanian: "Lungu"}},
	&Name{Romanian, spellings{Romanian: "Lupan"}},
	&Name{Romanian, spellings{Romanian: "Lupescu"}},
	&Name{Romanian, spellings{Romanian: "Lupu"}},
	&Name{Romanian, spellings{Romanian: "Lupul"}},
	&Name{Romanian, spellings{Romanian: "Macedonski"}},
	&Name{Romanian, spellings{Romanian: "Maftei"}},
	&Name{French, spellings{French: "Abadie"}},
	&Name{French, spellings{French: "Abbadie"}},
	&Name{French, spellings{French: "About"}},
	&Name{French, spellings{French: "D'Aboville"}},
	&Name{French, spellings{French: "Adnet"}},
	&Name{French, spellings{French: "Affré"}},
	&Name{French, spellings{French: "Alard"}},
	&Name{French, spellings{French: "Alarie"}},
	&Name{French, spellings{French: "Aliker"}},
	&Name{French, spellings{French: "Allaire"}},
	&Name{French, spellings{French: "Allais"}},
	&Name{French, spellings{French: "Allard"}},
	&Name{French, spellings{French: "Allemand"}},
	&Name{French, spellings{French: "Alméras"}},
	&Name{French, spellings{French: "D'Amboise"}},
	&Name{French, spellings{French: "Ancel"}},
	&Name{French, spellings{French: "Ange"}},
	&Name{French, spellings{French: "Appell"}},
	&Name{French, spellings{French: "Arceneaux"}},
	&Name{French, spellings{French: "Ardouin"}},
	&Name{French, spellings{French: "Arsenault"}},
	&Name{French, spellings{French: "Arseneau"}},
	&Name{French, spellings{French: "Arseneault"}},
	&Name{French, spellings{French: "Asselin"}},
	&Name{French, spellings{French: "Asselineau"}},
	&Name{French, spellings{French: "Astier"}},
	&Name{French, spellings{French: "Auberjonois"}},
	&Name{French, spellings{French: "Aubert"}},
	&Name{French, spellings{French: "Auclair"}},
	&Name{French, spellings{French: "Auger"}},
	&Name{French, spellings{French: "Auguste"}},
	&Name{French, spellings{French: "Auvray"}},
	&Name{French, spellings{French: "Aveline"}},
	&Name{French, spellings{French: "Azaïs"}},
	&Name{French, spellings{French: "Azéma"}},
	&Name{French, spellings{French: "Bachelet"}},
	&Name{French, spellings{French: "Bachelot"}},
	&Name{French, spellings{French: "Bacque"}},
	&Name{French, spellings{French: "Badeaux"}},
	&Name{French, spellings{French: "Baillairgé"}},
	&Name{French, spellings{French: "Baillieu"}},
	&Name{French, spellings{French: "Bain"}},
	&Name{French, spellings{French: "Ballesdens"}},
	&Name{French, spellings{French: "Ballouhey"}},
	&Name{French, spellings{French: "Balzac"}},
	&Name{French, spellings{French: "Barbeau"}},
	&Name{French, spellings{French: "Barbet"}},
	&Name{French, spellings{French: "Barbier"}},
	&Name{French, spellings{French: "Bardin"}},
	&Name{French, spellings{French: "Barnier"}},
	&Name{French, spellings{French: "Barrande"}},
	&Name{French, spellings{French: "Barrault"}},
	&Name{French, spellings{French: "Barreau"}},
	&Name{French, spellings{French: "Barthélemy"}},
	&Name{French, spellings{French: "Barthet"}},
	&Name{French, spellings{French: "Baschet"}},
	&Name{French, spellings{French: "Bassot"}},
	&Name{French, spellings{French: "Batteux"}},
	&Name{French, spellings{French: "Battier"}},
	&Name{French, spellings{French: "Baudelaire"}},
	&Name{French, spellings{French: "Baudet"}},
	&Name{French, spellings{French: "Baugé"}},
	&Name{French, spellings{French: "Baumé"}},
	&Name{French, spellings{French: "Baume"}},
	&Name{French, spellings{French: "Bazalgette"}},
	&Name{French, spellings{French: "Beaubois"}},
	&Name{French, spellings{French: "Beauchamp"}},
	&Name{French, spellings{French: "Beaudouin"}},
	&Name{French, spellings{French: "Beaufils"}},
	&Name{French, spellings{French: "Beaugendre"}},
	&Name{French, spellings{French: "Beaulieu"}},
	&Name{French, spellings{French: "Beaulne"}},
	&Name{French, spellings{French: "Beaumanoir"}},
	&Name{French, spellings{French: "Beaumont"}},
	&Name{French, spellings{French: "Beauregard"}},
	&Name{French, spellings{French: "Beausoleil"}},
	&Name{French, spellings{French: "Beauvais"}},
	&Name{French, spellings{French: "Beauvau"}},
	&Name{French, spellings{French: "Beauvilliers"}},
	&Name{French, spellings{French: "Beaux"}},
	&Name{French, spellings{French: "Bebout"}},
	&Name{French, spellings{French: "Bechard"}},
	&Name{French, spellings{French: "Bélanger"}},
	&Name{French, spellings{French: "Béliveau"}},
	&Name{French, spellings{French: "Bellegarde"}},
	&Name{French, spellings{French: "Belyea"}},
	&Name{French, spellings{French: "Benett"}},
	&Name{French, spellings{French: "Benoît"}},
	&Name{French, spellings{French: "Béraud"}},
	&Name{French, spellings{French: "Berengar"}},
	&Name{French, spellings{French: "Berger"}},
	&Name{French, spellings{French: "Bergier"}},
	&Name{French, spellings{French: "Berlioz"}},
	&Name{French, spellings{French: "Bernier"}},
	&Name{French, spellings{French: "Berthelot"}},
	&Name{French, spellings{French: "Bertillon"}},
	&Name{French, spellings{French: "Bescond"}},
	&Name{French, spellings{French: "Besnard"}},
	&Name{French, spellings{French: "Bessette"}},
	&Name{French, spellings{French: "Besson"}},
	&Name{French, spellings{French: "Bethune"}},
	&Name{French, spellings{French: "Bettencourt"}},
	&Name{French, spellings{French: "Bissonnette"}},
	&Name{French, spellings{French: "Bittencourt"}},
	&Name{French, spellings{French: "Blaise"}},
	&Name{French, spellings{French: "Blanc"}},
	&Name{French, spellings{French: "Blanchard"}},
	&Name{French, spellings{French: "Blanchet"}},
	&Name{French, spellings{French: "Blondeau"}},
	&Name{French, spellings{French: "Bocuse"}},
	&Name{French, spellings{French: "Boffrand"}},
	&Name{French, spellings{French: "Boisselot"}},
	&Name{French, spellings{French: "Boissieu"}},
	&Name{French, spellings{French: "Boissonade"}},
	&Name{French, spellings{French: "Bombelles"}},
	&Name{French, spellings{French: "Bonhomme"}},
	&Name{French, spellings{French: "Bonnel"}},
	&Name{French, spellings{French: "Bonnet"}},
	&Name{French, spellings{French: "Bonnot"}},
	&Name{French, spellings{French: "Bossuet"}},
	&Name{French, spellings{French: "Botrel"}},
	&Name{French, spellings{French: "Bouchard"}},
	&Name{French, spellings{French: "Boucher"}},
	&Name{French, spellings{French: "Boudet"}},
	&Name{French, spellings{French: "Boudier"}},
	&Name{French, spellings{French: "Boudon"}},
	&Name{French, spellings{French: "Boudreaux"}},
	&Name{French, spellings{French: "Bougie"}},
	&Name{French, spellings{French: "Bouhier"}},
	&Name{French, spellings{French: "Boulanger"}},
	&Name{French, spellings{French: "Boulet"}},
	&Name{French, spellings{French: "Boulle"}},
	&Name{French, spellings{French: "Bourbeau"}},
	&Name{French, spellings{French: "Bourcier"}},
	&Name{French, spellings{French: "Bourdon"}},
	&Name{French, spellings{French: "Bourgeois"}},
	&Name{French, spellings{French: "Bourguignon"}},
	&Name{French, spellings{French: "Bourque"}},
	&Name{French, spellings{French: "Bourseiller"}},
	&Name{French, spellings{French: "Bousquet"}},
	&Name{French, spellings{French: "Boutet"}},
	&Name{French, spellings{French: "Bouthillier"}},
	&Name{French, spellings{French: "Boutin"}},
	&Name{French, spellings{French: "Boutroux"}},
	&Name{French, spellings{French: "Bozonnet"}},
	&Name{French, spellings{French: "Brassard"}},
	&Name{French, spellings{French: "Brasseur"}},
	&Name{French, spellings{French: "Breguet"}},
	&Name{French, spellings{French: "Brian"}},
	&Name{French, spellings{French: "Brochard"}},
	&Name{French, spellings{French: "Brosseau"}},
	&Name{French, spellings{French: "Brousseau"}},
	&Name{French, spellings{French: "Brugière"}},
	&Name{French, spellings{French: "Bruguière"}},
	&Name{French, spellings{French: "Bruneau"}},
	&Name{French, spellings{French: "Brunelle"}},
	&Name{French, spellings{French: "Brunet"}},
	&Name{French, spellings{French: "Bullion"}},
	&Name{French, spellings{French: "Bureau"}},
	&Name{French, spellings{French: "Cahun"}},
	&Name{French, spellings{French: "Caillat"}},
	&Name{French, spellings{French: "Cailloux"}},
	&Name{French, spellings{French: "Calvet"}},
	&Name{French, spellings{French: "Camille"}},
	&Name{French, spellings{French: "Carbonneau"}},
	&Name{French, spellings{French: "Carpentier"}},
	&Name{French, spellings{French: "Carré"}},
	&Name{French, spellings{French: "Carrel"}},
	&Name{French, spellings{French: "Carrell"}},
	&Name{French, spellings{French: "Cartier"}},
	&Name{French, spellings{French: "Castex"}},
	&Name{French, spellings{French: "Castile"}},
	&Name{French, spellings{French: "Cazal"}},
	&Name{French, spellings{French: "Cazenave"}},
	&Name{French, spellings{French: "Celice"}},
	&Name{French, spellings{French: "Cellier"}},
	&Name{French, spellings{French: "Cerf"}},
	&Name{French, spellings{French: "Cerfbeer"}},
	&Name{French, spellings{French: "Chabert"}},
	&Name{French, spellings{French: "Chagnon"}},
	&Name{French, spellings{French: "Chaney"}},
	&Name{French, spellings{French: "Chapelle"}},
	&Name{French, spellings{French: "Chappelle"}},
	&Name{French, spellings{French: "Chappuis"}},
	&Name{French, spellings{French: "Chapuis"}},
	&Name{French, spellings{French: "Charbonneau"}},
	&Name{French, spellings{French: "Charbonnier"}},
	&Name{French, spellings{French: "Chardin"}},
	&Name{French, spellings{French: "Charlet"}},
	&Name{French, spellings{French: "Charpentier"}},
	&Name{French, spellings{French: "Charrier"}},
	&Name{French, spellings{French: "Chastain"}},
	&Name{French, spellings{French: "Chatelain"}},
	&Name{French, spellings{French: "Chaucer"}},
	&Name{French, spellings{French: "Chauffard"}},
	&Name{French, spellings{French: "Chaufourier"}},
	&Name{French, spellings{French: "Chausson"}},
}
